/**
 * Created by alexbol on 1/21/2018.
 */

'use strict';

import {expect} from 'chai';
//import Flatten from 'https://unpkg.com/@flatten-js/core';
//import {Polygon} from 'https://unpkg.com/@flatten-js/core';
//import {point, segment, arc, circle} from 'https://unpkg.com/@flatten-js/core';

import Flatten from '../../index';

import {Polygon} from '../../index';
import {point, circle, segment, arc} from '../../index';


import * as BooleanOp from "../../src/algorithms/boolean_op";
let {unify, subtract, intersect} = BooleanOp;

let {equal} = Flatten.Relations;

describe('#Algorithms.Boolean Operations', function () {
    describe('#Algorithms.Boolean Union', function () {
        it('Function unify defined', function () {
            expect(unify).to.exist;
            expect(unify).to.be.a('function');
        });
        // it('Function arrange defined', function () {
        //     expect(arrange).to.exist;
        //     expect(arrange).to.be.a('function');
        // });
        // it('Can arrange two polygons and add vertices', function () {
        //     "use strict";
        //     let poly1 = new Polygon();
        //     poly1.addFace([point(0, 0), point(150, 0), point(150, 30), point(0, 30)]);
        //     let poly2 = new Polygon();
        //     poly2.addFace([point(100, 20), point(200, 20), point(200, 40), point(100, 40)]);
        //     arrange(poly1, poly2);
        //     expect(poly1.edges.size).to.equal(6);
        //     expect(poly2.edges.size).to.equal(6);
        //     for (let face of poly1.faces) {
        //         expect(face.size).to.equal(6);
        //     }
        //     for (let face of poly2.faces) {
        //         expect(face.size).to.equal(6);
        //     }
        // });
        it('Can perform unify. 2 polygons, intersect', function () {
            "use strict";
            let poly1 = new Polygon();
            poly1.addFace([point(0, 0), point(150, 0), point(150, 30), point(0, 30)]);
            let poly2 = new Polygon();
            poly2.addFace([point(100, 20), point(200, 20), point(200, 40), point(100, 40)]);
            let poly = unify(poly1, poly2);
            expect(poly.faces.size).to.equal(1);
            for (let face of poly.faces) {
                expect(face.size).to.equal(8);
            }
            let vertices = poly.vertices;
            expect(vertices.find((pt) => pt.equalTo(point(0, 0)))).not.to.be.undefined;
            expect(vertices.find((pt) => pt.equalTo(point(150, 0)))).not.to.be.undefined;
            expect(vertices.find((pt) => pt.equalTo(point(150, 30)))).to.be.undefined;
            expect(vertices.find((pt) => pt.equalTo(point(0, 30)))).not.to.be.undefined;
            expect(vertices.find((pt) => pt.equalTo(point(100, 20)))).to.be.undefined;
            expect(vertices.find((pt) => pt.equalTo(point(200, 20)))).not.to.be.undefined;
            expect(vertices.find((pt) => pt.equalTo(point(200, 40)))).not.to.be.undefined;
            expect(vertices.find((pt) => pt.equalTo(point(100, 40)))).not.to.be.undefined;
        });
        it('Can perform unify. 2 polygons, disjoint', function () {
            "use strict";
            let poly1 = new Polygon();
            poly1.addFace([point(0, 0), point(50, 0), point(50, 30), point(0, 30)]);
            let poly2 = new Polygon();
            poly2.addFace([point(100, 50), point(200, 50), point(200, 100), point(100, 100)]);
            let poly = unify(poly1, poly2);
            expect(poly.faces.size).to.equal(2);
            for (let face of poly.faces) {
                expect(face.size).to.equal(4);
            }
        });
        it('Can perform unify. 2 polygons, 1 in 2', function () {
            "use strict";
            let poly1 = new Polygon();
            poly1.addFace([point(0, 0), point(50, 0), point(50, 30), point(0, 30)]);
            let poly2 = new Polygon();
            poly2.addFace([point(-100, -50), point(200, -50), point(200, 100), point(-100, 100)]);
            let poly = unify(poly1, poly2);
            expect(poly.faces.size).to.equal(1);
            for (let face of poly.faces) {
                expect(face.size).to.equal(4);
            }
        });
        it('Can perform unify. 2 polygons, 2 in 1', function () {
            "use strict";
            let poly1 = new Polygon();
            poly1.addFace([point(0, 0), point(50, 0), point(50, 30), point(0, 30)]);
            let poly2 = new Polygon();
            poly2.addFace([point(-100, -50), point(200, -50), point(200, 100), point(-100, 100)]);
            let poly = unify(poly2, poly1);
            expect(poly.faces.size).to.equal(1);
            expect(poly.edges.size).to.equal(4);
            for (let face of poly.faces) {
                expect(face.size).to.equal(4);
            }
        });
        it('Can perform unify. 2 polygons, 2 in 1 touching from inside, overlapping same', function () {
            "use strict";
            let poly1 = new Polygon();
            poly1.addFace([point(0, 0), point(50, 0), point(50, 30), point(0, 30)]);
            expect([...poly1.edges][0].shape instanceof Flatten.Segment).to.be.true;
            let poly2 = new Polygon();
            poly2.addFace([point(25, 0), point(50, 0), point(50, 15), point(25, 15)]);
            let poly = unify(poly1, poly2);
            expect(poly.faces.size).to.equal(1);
            expect(poly.edges.size).to.equal(6);
        });
        it('Can perform unify. 2 polygons, 2 in 1 touching from outside, overlapping opposite', function () {
            "use strict";

            let polygon1 = new Polygon();
            polygon1.addFace([
                segment(-50, -50, 50, -50),
                segment(50, -50, 50, 50),
                segment(50, 50, -50, 50),
                segment(-50, 50, -50, -50)
            ]);

            let polygon2 = new Polygon();
            polygon2.addFace([
                segment(0, 50, 100, 50),
                segment(100, 50, 100, 100),
                segment(100, 100, 0, 100),
                segment(0, 100, 0, 50)
            ]);

            let poly = unify(polygon1, polygon2);
            expect(poly.faces.size).to.equal(1);
            expect(poly.edges.size).to.equal(8);
        });
        it('Can perform unify. 2 polygons form cross-shape', function () {
            "use strict";

            let polygon1 = new Polygon();
            polygon1.addFace([
                point(-10, 0),
                point(10, 0),
                point(10, 80),
                point(-10, 80)
            ]);
            let polygon2 = new Polygon();
            polygon2.addFace([
                point(-40, 30),
                point(40, 30),
                point(40, 50),
                point(-40, 50)
            ]);

            let poly = unify(polygon1, polygon2);
            expect(poly.faces.size).to.equal(1);
            expect(poly.edges.size).to.equal(12);
        });
        it('Can perform unify. 2 disjoint polygons', function () {
            "use strict";

            let polygon1 = new Polygon();
            polygon1.addFace([
                point(-10, 0),
                point(10, 0),
                point(10, 20),
                point(-10, 20)
            ]);
            let polygon2 = new Polygon();
            polygon2.addFace([
                point(-40, 30),
                point(40, 30),
                point(40, 50),
                point(-40, 50)
            ]);

            let poly = unify(polygon1, polygon2);
            expect(poly.faces.size).to.equal(2);
            expect(poly.edges.size).to.equal(8);
        });
        it('Can perform unify. 1st polygon with one round hole, 2nd polygon partially intersect hole ', function () {
            "use strict";

            let polygon1 = new Polygon();
            polygon1.addFace([
                point(-10, 0),
                point(-10, 20),
                point(10, 20),
                point(10, 0)
            ]);
            polygon1.addFace(
                [circle(point(0, 10), 5).toArc(true)]
            );
            let polygon2 = new Polygon();
            polygon2.addFace([
                point(-40, 13),
                point(-40, 50),
                point(40, 50),
                point(40, 13)
            ]);

            let poly = unify(polygon1, polygon2);
            expect(poly.faces.size).to.equal(2);
            let faces = [...poly.faces];
            expect(faces[0].size).to.equal(8);
            expect(faces[1].size).to.equal(3);
            expect(poly.edges.size).to.equal(11);
        });
        it('Can perform unify. 1st polygon with one round hole, 2nd polygon fully cover hole ', function () {
            "use strict";

            let polygon1 = new Polygon();
            polygon1.addFace([
                point(-10, 0),
                point(-10, 20),
                point(10, 20),
                point(10, 0)
            ]);
            polygon1.addFace(
                [circle(point(0, 10), 5).toArc(true)]
            );

            let polygon2 = new Polygon();
            polygon2.addFace([
                point(-8, 2),
                point(-8, 18),
                point(8, 18),
                point(8, 2)
            ]);

            let poly = unify(polygon1, polygon2);
            expect(poly.faces.size).to.equal(1);
            expect(poly.edges.size).to.equal(4);
        });
        it('Can perform unify. 2 polygons create one triangular hole after unify', function () {
            "use strict";

            let polygon1 = new Polygon();
            polygon1.addFace([point(100,10), point(100, 300), point(350, 300),point(150, 150), point(350, 10)]);

            let polygon2 = new Polygon();
            polygon2.addFace([point(400, 10), point(300, 10), point(300,300), point(400, 300)]);


            let poly = unify(polygon1, polygon2);
            expect(poly.faces.size).to.equal(2);
            expect([...poly.faces][0].size).to.equal(8);
            expect([...poly.faces][0].orientation()).to.equal(Flatten.ORIENTATION.CW);
            expect([...poly.faces][1].size).to.equal(3);
            expect([...poly.faces][1].orientation()).to.equal(Flatten.ORIENTATION.CCW);
            expect(poly.edges.size).to.equal(11);
        });
        it('Can perform unify. Infinite loop for boolean union over (valid) polygons. Issue #53', function () {
            "use strict";

            const json1 = `[[{"ps":{"x":495.6999999999999,"y":449.6,"name":"point"},"pe":{"x":500.62352941176465,"y":449.6,"name":"point"},"name":"segment"},{"ps":{"x":500.62352941176465,"y":449.6,"name":"point"},"pe":{"x":500.8,"y":449.5,"name":"point"},"name":"segment"},{"ps":{"x":500.8,"y":449.5,"name":"point"},"pe":{"x":501.6222222222222,"y":448.67777777777775,"name":"point"},"name":"segment"},{"ps":{"x":501.6222222222222,"y":448.67777777777775,"name":"point"},"pe":{"x":504.8,"y":448.8,"name":"point"},"name":"segment"},{"ps":{"x":504.8,"y":448.8,"name":"point"},"pe":{"x":507.11999999999995,"y":448.21999999999997,"name":"point"},"name":"segment"},{"ps":{"x":507.11999999999995,"y":448.21999999999997,"name":"point"},"pe":{"x":507.5,"y":448.2,"name":"point"},"name":"segment"},{"ps":{"x":507.5,"y":448.2,"name":"point"},"pe":{"x":510.16305569749636,"y":447.76647930505874,"name":"point"},"name":"segment"},{"ps":{"x":510.16305569749636,"y":447.76647930505874,"name":"point"},"pe":{"x":512.0000000000002,"y":445.64999999999986,"name":"point"},"name":"segment"},{"ps":{"x":512.0000000000002,"y":445.64999999999986,"name":"point"},"pe":{"x":512.2,"y":443.8,"name":"point"},"name":"segment"},{"ps":{"x":512.2,"y":443.8,"name":"point"},"pe":{"x":512.4352941176471,"y":442.9529411764702,"name":"point"},"name":"segment"},{"ps":{"x":512.4352941176471,"y":442.9529411764702,"name":"point"},"pe":{"x":513.3,"y":441.8,"name":"point"},"name":"segment"},{"ps":{"x":513.3,"y":441.8,"name":"point"},"pe":{"x":515.0562499999997,"y":438.2875000000002,"name":"point"},"name":"segment"},{"ps":{"x":515.0562499999997,"y":438.2875000000002,"name":"point"},"pe":{"x":516.5,"y":436.8,"name":"point"},"name":"segment"},{"ps":{"x":516.5,"y":436.8,"name":"point"},"pe":{"x":516.5893617021277,"y":435.22127659574465,"name":"point"},"name":"segment"},{"ps":{"x":516.5893617021277,"y":435.22127659574465,"name":"point"},"pe":{"x":519.8,"y":428.8,"name":"point"},"name":"segment"},{"ps":{"x":519.8,"y":428.8,"name":"point"},"pe":{"x":521.3303326810178,"y":426.90958904109596,"name":"point"},"name":"segment"},{"ps":{"x":521.3303326810178,"y":426.90958904109596,"name":"point"},"pe":{"x":521.8,"y":426.8,"name":"point"},"name":"segment"},{"ps":{"x":521.8,"y":426.8,"name":"point"},"pe":{"x":523.5,"y":426.8,"name":"point"},"name":"segment"},{"ps":{"x":523.5,"y":426.8,"name":"point"},"pe":{"x":524.4297872340426,"y":423.08085106382975,"name":"point"},"name":"segment"},{"ps":{"x":524.4297872340426,"y":423.08085106382975,"name":"point"},"pe":{"x":526.8443113772455,"y":420.0982035928144,"name":"point"},"name":"segment"},{"ps":{"x":526.8443113772455,"y":420.0982035928144,"name":"point"},"pe":{"x":527,"y":419.6,"name":"point"},"name":"segment"},{"ps":{"x":527,"y":419.6,"name":"point"},"pe":{"x":527.254258675079,"y":419.5917981072555,"name":"point"},"name":"segment"},{"ps":{"x":527.254258675079,"y":419.5917981072555,"name":"point"},"pe":{"x":528.3,"y":418.3,"name":"point"},"name":"segment"},{"ps":{"x":528.3,"y":418.3,"name":"point"},"pe":{"x":536.9370833333332,"y":418.7545833333333,"name":"point"},"name":"segment"},{"ps":{"x":536.9370833333332,"y":418.7545833333333,"name":"point"},"pe":{"x":537.4696969696968,"y":419.7437229437229,"name":"point"},"name":"segment"},{"ps":{"x":537.4696969696968,"y":419.7437229437229,"name":"point"},"pe":{"x":536.273933649289,"y":423.1601895734599,"name":"point"},"name":"segment"},{"ps":{"x":536.273933649289,"y":423.1601895734599,"name":"point"},"pe":{"x":536.2,"y":423.2,"name":"point"},"name":"segment"},{"ps":{"x":536.2,"y":423.2,"name":"point"},"pe":{"x":534.5,"y":425.5,"name":"point"},"name":"segment"},{"ps":{"x":534.5,"y":425.5,"name":"point"},"pe":{"x":534.2,"y":428.2,"name":"point"},"name":"segment"},{"ps":{"x":534.2,"y":428.2,"name":"point"},"pe":{"x":534.2,"y":428.94999999999993,"name":"point"},"name":"segment"},{"ps":{"x":534.2,"y":428.94999999999993,"name":"point"},"pe":{"x":533,"y":430.75000000000006,"name":"point"},"name":"segment"},{"ps":{"x":533,"y":430.75000000000006,"name":"point"},"pe":{"x":533,"y":431,"name":"point"},"name":"segment"},{"ps":{"x":533,"y":431,"name":"point"},"pe":{"x":531.7,"y":433.6,"name":"point"},"name":"segment"},{"ps":{"x":531.7,"y":433.6,"name":"point"},"pe":{"x":533.1409937888199,"y":438.10310559006217,"name":"point"},"name":"segment"},{"ps":{"x":533.1409937888199,"y":438.10310559006217,"name":"point"},"pe":{"x":533.9477732793523,"y":438.8202429149798,"name":"point"},"name":"segment"},{"ps":{"x":533.9477732793523,"y":438.8202429149798,"name":"point"},"pe":{"x":534.74578313253,"y":439.0915662650602,"name":"point"},"name":"segment"},{"ps":{"x":534.74578313253,"y":439.0915662650602,"name":"point"},"pe":{"x":534.8,"y":439.2,"name":"point"},"name":"segment"},{"ps":{"x":534.8,"y":439.2,"name":"point"},"pe":{"x":534.9610738255034,"y":439.1647651006711,"name":"point"},"name":"segment"},{"ps":{"x":534.9610738255034,"y":439.1647651006711,"name":"point"},"pe":{"x":538.3,"y":440.3,"name":"point"},"name":"segment"},{"ps":{"x":538.3,"y":440.3,"name":"point"},"pe":{"x":539.5378516624038,"y":440.2015345268543,"name":"point"},"name":"segment"},{"ps":{"x":539.5378516624038,"y":440.2015345268543,"name":"point"},"pe":{"x":540.8,"y":439.3,"name":"point"},"name":"segment"},{"ps":{"x":540.8,"y":439.3,"name":"point"},"pe":{"x":545.4874999999998,"y":437.8,"name":"point"},"name":"segment"},{"ps":{"x":545.4874999999998,"y":437.8,"name":"point"},"pe":{"x":545.5,"y":437.8,"name":"point"},"name":"segment"},{"ps":{"x":545.5,"y":437.8,"name":"point"},"pe":{"x":545.8000000000042,"y":437.69999999999834,"name":"point"},"name":"segment"},{"ps":{"x":545.8000000000042,"y":437.69999999999834,"name":"point"},"pe":{"x":553.3,"y":435.3,"name":"point"},"name":"segment"},{"ps":{"x":553.3,"y":435.3,"name":"point"},"pe":{"x":559.8,"y":432.3,"name":"point"},"name":"segment"},{"ps":{"x":559.8,"y":432.3,"name":"point"},"pe":{"x":560.3625,"y":432.6,"name":"point"},"name":"segment"},{"ps":{"x":560.3625,"y":432.6,"name":"point"},"pe":{"x":561.3,"y":432.6,"name":"point"},"name":"segment"},{"ps":{"x":561.3,"y":432.6,"name":"point"},"pe":{"x":563.7,"y":433.6,"name":"point"},"name":"segment"},{"ps":{"x":563.7,"y":433.6,"name":"point"},"pe":{"x":565.5,"y":434.7,"name":"point"},"name":"segment"},{"ps":{"x":565.5,"y":434.7,"name":"point"},"pe":{"x":566.6864516129033,"y":434.43634408602156,"name":"point"},"name":"segment"},{"ps":{"x":566.6864516129033,"y":434.43634408602156,"name":"point"},"pe":{"x":566.8,"y":434.5,"name":"point"},"name":"segment"},{"ps":{"x":566.8,"y":434.5,"name":"point"},"pe":{"x":566.8888888888888,"y":434.3913580246913,"name":"point"},"name":"segment"},{"ps":{"x":566.8888888888888,"y":434.3913580246913,"name":"point"},"pe":{"x":567.7186046511628,"y":434.2069767441861,"name":"point"},"name":"segment"},{"ps":{"x":567.7186046511628,"y":434.2069767441861,"name":"point"},"pe":{"x":567.9382352941177,"y":433.1088235294116,"name":"point"},"name":"segment"},{"ps":{"x":567.9382352941177,"y":433.1088235294116,"name":"point"},"pe":{"x":569.5,"y":431.2,"name":"point"},"name":"segment"},{"ps":{"x":569.5,"y":431.2,"name":"point"},"pe":{"x":570.2,"y":427.8,"name":"point"},"name":"segment"},{"ps":{"x":570.2,"y":427.8,"name":"point"},"pe":{"x":570.5,"y":423.5,"name":"point"},"name":"segment"},{"ps":{"x":570.5,"y":423.5,"name":"point"},"pe":{"x":570.0223880597015,"y":422.68805970149253,"name":"point"},"name":"segment"},{"ps":{"x":570.0223880597015,"y":422.68805970149253,"name":"point"},"pe":{"x":570.3,"y":421.3,"name":"point"},"name":"segment"},{"ps":{"x":570.3,"y":421.3,"name":"point"},"pe":{"x":571.3015384615386,"y":420.96615384615376,"name":"point"},"name":"segment"},{"ps":{"x":571.3015384615386,"y":420.96615384615376,"name":"point"},"pe":{"x":571.7,"y":419.6,"name":"point"},"name":"segment"},{"ps":{"x":571.7,"y":419.6,"name":"point"},"pe":{"x":574.7,"y":419,"name":"point"},"name":"segment"},{"ps":{"x":574.7,"y":419,"name":"point"},"pe":{"x":575.7,"y":420,"name":"point"},"name":"segment"},{"ps":{"x":575.7,"y":420,"name":"point"},"pe":{"x":578,"y":426.3,"name":"point"},"name":"segment"},{"ps":{"x":578,"y":426.3,"name":"point"},"pe":{"x":579.8,"y":426.3,"name":"point"},"name":"segment"},{"ps":{"x":579.8,"y":426.3,"name":"point"},"pe":{"x":586.8,"y":422.8,"name":"point"},"name":"segment"},{"ps":{"x":586.8,"y":422.8,"name":"point"},"pe":{"x":594.3000000000028,"y":420.2999999999991,"name":"point"},"name":"segment"},{"ps":{"x":594.3000000000028,"y":420.2999999999991,"name":"point"},"pe":{"x":595.8,"y":419.8,"name":"point"},"name":"segment"},{"ps":{"x":595.8,"y":419.8,"name":"point"},"pe":{"x":595.3484804630967,"y":421.5308248914614,"name":"point"},"name":"segment"},{"ps":{"x":595.3484804630967,"y":421.5308248914614,"name":"point"},"pe":{"x":596.6,"y":423,"name":"point"},"name":"segment"},{"ps":{"x":596.6,"y":423,"name":"point"},"pe":{"x":596.7947261663286,"y":423.03245436105476,"name":"point"},"name":"segment"},{"ps":{"x":596.7947261663286,"y":423.03245436105476,"name":"point"},"pe":{"x":593.5,"y":429.8,"name":"point"},"name":"segment"},{"ps":{"x":593.5,"y":429.8,"name":"point"},"pe":{"x":595.5,"y":435.5,"name":"point"},"name":"segment"},{"ps":{"x":595.5,"y":435.5,"name":"point"},"pe":{"x":596.1461538461541,"y":437.9923076923084,"name":"point"},"name":"segment"},{"ps":{"x":596.1461538461541,"y":437.9923076923084,"name":"point"},"pe":{"x":596.2464285714285,"y":438.1928571428571,"name":"point"},"name":"segment"},{"ps":{"x":596.2464285714285,"y":438.1928571428571,"name":"point"},"pe":{"x":598.8,"y":437.8,"name":"point"},"name":"segment"},{"ps":{"x":598.8,"y":437.8,"name":"point"},"pe":{"x":599.8811403508773,"y":436.33728070175425,"name":"point"},"name":"segment"},{"ps":{"x":599.8811403508773,"y":436.33728070175425,"name":"point"},"pe":{"x":602.7764127764127,"y":429.43316953316935,"name":"point"},"name":"segment"},{"ps":{"x":602.7764127764127,"y":429.43316953316935,"name":"point"},"pe":{"x":602.2,"y":427.8,"name":"point"},"name":"segment"},{"ps":{"x":602.2,"y":427.8,"name":"point"},"pe":{"x":602.2,"y":425.5,"name":"point"},"name":"segment"},{"ps":{"x":602.2,"y":425.5,"name":"point"},"pe":{"x":602.7065743944636,"y":424.0647058823528,"name":"point"},"name":"segment"},{"ps":{"x":602.7065743944636,"y":424.0647058823528,"name":"point"},"pe":{"x":605.4,"y":425.7,"name":"point"},"name":"segment"},{"ps":{"x":605.4,"y":425.7,"name":"point"},"pe":{"x":604.8,"y":425.8,"name":"point"},"name":"segment"},{"ps":{"x":604.8,"y":425.8,"name":"point"},"pe":{"x":605.3161290322583,"y":426.02580645161305,"name":"point"},"name":"segment"},{"ps":{"x":605.3161290322583,"y":426.02580645161305,"name":"point"},"pe":{"x":605.8206896551726,"y":426.13793103448296,"name":"point"},"name":"segment"},{"ps":{"x":605.8206896551726,"y":426.13793103448296,"name":"point"},"pe":{"x":605.6,"y":426,"name":"point"},"name":"segment"},{"ps":{"x":605.6,"y":426,"name":"point"},"pe":{"x":607.4349083895853,"y":425.97261330761813,"name":"point"},"name":"segment"},{"ps":{"x":607.4349083895853,"y":425.97261330761813,"name":"point"},"pe":{"x":609.2,"y":426.8,"name":"point"},"name":"segment"},{"ps":{"x":609.2,"y":426.8,"name":"point"},"pe":{"x":609.8233025984912,"y":425.93696563285835,"name":"point"},"name":"segment"},{"ps":{"x":609.8233025984912,"y":425.93696563285835,"name":"point"},"pe":{"x":612.3,"y":425.9,"name":"point"},"name":"segment"},{"ps":{"x":612.3,"y":425.9,"name":"point"},"pe":{"x":613.3,"y":424,"name":"point"},"name":"segment"},{"ps":{"x":613.3,"y":424,"name":"point"},"pe":{"x":614.610344827586,"y":423.541379310345,"name":"point"},"name":"segment"},{"ps":{"x":614.610344827586,"y":423.541379310345,"name":"point"},"pe":{"x":614.8,"y":423.3,"name":"point"},"name":"segment"},{"ps":{"x":614.8,"y":423.3,"name":"point"},"pe":{"x":615.2200000000003,"y":423.32800000000003,"name":"point"},"name":"segment"},{"ps":{"x":615.2200000000003,"y":423.32800000000003,"name":"point"},"pe":{"x":615.3,"y":423.3,"name":"point"},"name":"segment"},{"ps":{"x":615.3,"y":423.3,"name":"point"},"pe":{"x":615.7051724137923,"y":423.3603448275862,"name":"point"},"name":"segment"},{"ps":{"x":615.7051724137923,"y":423.3603448275862,"name":"point"},"pe":{"x":620.4450381679391,"y":423.6763358778625,"name":"point"},"name":"segment"},{"ps":{"x":620.4450381679391,"y":423.6763358778625,"name":"point"},"pe":{"x":623.3,"y":421.6000000000001,"name":"point"},"name":"segment"},{"ps":{"x":623.3,"y":421.6000000000001,"name":"point"},"pe":{"x":625.3999999999997,"y":416.98,"name":"point"},"name":"segment"},{"ps":{"x":625.3999999999997,"y":416.98,"name":"point"},"pe":{"x":625.8,"y":416.5,"name":"point"},"name":"segment"},{"ps":{"x":625.8,"y":416.5,"name":"point"},"pe":{"x":627.5209302325579,"y":412.3139534883709,"name":"point"},"name":"segment"},{"ps":{"x":627.5209302325579,"y":412.3139534883709,"name":"point"},"pe":{"x":629.1474264705897,"y":408.73566176470115,"name":"point"},"name":"segment"},{"ps":{"x":629.1474264705897,"y":408.73566176470115,"name":"point"},"pe":{"x":629.4144013880857,"y":407.708212839792,"name":"point"},"name":"segment"},{"ps":{"x":629.4144013880857,"y":407.708212839792,"name":"point"},"pe":{"x":629.5,"y":407.5,"name":"point"},"name":"segment"},{"ps":{"x":629.5,"y":407.5,"name":"point"},"pe":{"x":629.4893858984078,"y":407.4196360879452,"name":"point"},"name":"segment"},{"ps":{"x":629.4893858984078,"y":407.4196360879452,"name":"point"},"pe":{"x":630.3,"y":404.3,"name":"point"},"name":"segment"},{"ps":{"x":630.3,"y":404.3,"name":"point"},"pe":{"x":633.3,"y":397,"name":"point"},"name":"segment"},{"ps":{"x":633.3,"y":397,"name":"point"},"pe":{"x":634.6,"y":396.74,"name":"point"},"name":"segment"},{"ps":{"x":634.6,"y":396.74,"name":"point"},"pe":{"x":634.8,"y":396.3,"name":"point"},"name":"segment"},{"ps":{"x":634.8,"y":396.3,"name":"point"},"pe":{"x":635.2472049689441,"y":396.61055900621113,"name":"point"},"name":"segment"},{"ps":{"x":635.2472049689441,"y":396.61055900621113,"name":"point"},"pe":{"x":635.3,"y":396.6,"name":"point"},"name":"segment"},{"ps":{"x":635.3,"y":396.6,"name":"point"},"pe":{"x":635.3136504014824,"y":396.65670166769615,"name":"point"},"name":"segment"},{"ps":{"x":635.3136504014824,"y":396.65670166769615,"name":"point"},"pe":{"x":635.8961248112734,"y":397.0611977856065,"name":"point"},"name":"segment"},{"ps":{"x":635.8961248112734,"y":397.0611977856065,"name":"point"},"pe":{"x":637.2,"y":402.2,"name":"point"},"name":"segment"},{"ps":{"x":637.2,"y":402.2,"name":"point"},"pe":{"x":637.8,"y":409.8,"name":"point"},"name":"segment"},{"ps":{"x":637.8,"y":409.8,"name":"point"},"pe":{"x":650.3633187772926,"y":407.1078602620087,"name":"point"},"name":"segment"},{"ps":{"x":650.3633187772926,"y":407.1078602620087,"name":"point"},"pe":{"x":652.8,"y":408.8,"name":"point"},"name":"segment"},{"ps":{"x":652.8,"y":408.8,"name":"point"},"pe":{"x":654.1391684901531,"y":411.7759299781182,"name":"point"},"name":"segment"},{"ps":{"x":654.1391684901531,"y":411.7759299781182,"name":"point"},"pe":{"x":653.8589003054708,"y":411.99025270758113,"name":"point"},"name":"segment"},{"ps":{"x":653.8589003054708,"y":411.99025270758113,"name":"point"},"pe":{"x":659.9,"y":424.9,"name":"point"},"name":"segment"},{"ps":{"x":659.9,"y":424.9,"name":"point"},"pe":{"x":660.1636363636363,"y":425.16363636363616,"name":"point"},"name":"segment"},{"ps":{"x":660.1636363636363,"y":425.16363636363616,"name":"point"},"pe":{"x":660.4747252747255,"y":425.8549450549451,"name":"point"},"name":"segment"},{"ps":{"x":660.4747252747255,"y":425.8549450549451,"name":"point"},"pe":{"x":660.95,"y":425.95,"name":"point"},"name":"segment"},{"ps":{"x":660.95,"y":425.95,"name":"point"},"pe":{"x":662.6285714285714,"y":427.62857142857126,"name":"point"},"name":"segment"},{"ps":{"x":662.6285714285714,"y":427.62857142857126,"name":"point"},"pe":{"x":662.8,"y":428.2,"name":"point"},"name":"segment"},{"ps":{"x":662.8,"y":428.2,"name":"point"},"pe":{"x":662.8,"y":428.5222222222222,"name":"point"},"name":"segment"},{"ps":{"x":662.8,"y":428.5222222222222,"name":"point"},"pe":{"x":663.3652173913043,"y":428.36521739130427,"name":"point"},"name":"segment"},{"ps":{"x":663.3652173913043,"y":428.36521739130427,"name":"point"},"pe":{"x":664.3,"y":429.3,"name":"point"},"name":"segment"},{"ps":{"x":664.3,"y":429.3,"name":"point"},"pe":{"x":666.7,"y":429.9,"name":"point"},"name":"segment"},{"ps":{"x":666.7,"y":429.9,"name":"point"},"pe":{"x":676.9880421243348,"y":424.80405390103044,"name":"point"},"name":"segment"},{"ps":{"x":676.9880421243348,"y":424.80405390103044,"name":"point"},"pe":{"x":677.0046511627908,"y":424.6,"name":"point"},"name":"segment"},{"ps":{"x":677.0046511627908,"y":424.6,"name":"point"},"pe":{"x":676.9199999999996,"y":424.6,"name":"point"},"name":"segment"},{"ps":{"x":676.9199999999996,"y":424.6,"name":"point"},"pe":{"x":677.0066093853271,"y":424.57594183740895,"name":"point"},"name":"segment"},{"ps":{"x":677.0066093853271,"y":424.57594183740895,"name":"point"},"pe":{"x":677.0326693227092,"y":424.2557768924303,"name":"point"},"name":"segment"},{"ps":{"x":677.0326693227092,"y":424.2557768924303,"name":"point"},"pe":{"x":679,"y":423.6,"name":"point"},"name":"segment"},{"ps":{"x":679,"y":423.6,"name":"point"},"pe":{"x":682.357482185273,"y":421.67707838479805,"name":"point"},"name":"segment"},{"ps":{"x":682.357482185273,"y":421.67707838479805,"name":"point"},"pe":{"x":682.8,"y":421.8,"name":"point"},"name":"segment"},{"ps":{"x":682.8,"y":421.8,"name":"point"},"pe":{"x":682.8180505415162,"y":421.8794223826715,"name":"point"},"name":"segment"},{"ps":{"x":682.8180505415162,"y":421.8794223826715,"name":"point"},"pe":{"x":687.5974683544301,"y":418.8379746835445,"name":"point"},"name":"segment"},{"ps":{"x":687.5974683544301,"y":418.8379746835445,"name":"point"},"pe":{"x":687.6086956521738,"y":418.66956521739127,"name":"point"},"name":"segment"},{"ps":{"x":687.6086956521738,"y":418.66956521739127,"name":"point"},"pe":{"x":690,"y":417.3,"name":"point"},"name":"segment"},{"ps":{"x":690,"y":417.3,"name":"point"},"pe":{"x":690.0055555555555,"y":417.30555555555554,"name":"point"},"name":"segment"},{"ps":{"x":690.0055555555555,"y":417.30555555555554,"name":"point"},"pe":{"x":690.8,"y":416.8,"name":"point"},"name":"segment"},{"ps":{"x":690.8,"y":416.8,"name":"point"},"pe":{"x":692.8728943338436,"y":417.77886676875954,"name":"point"},"name":"segment"},{"ps":{"x":692.8728943338436,"y":417.77886676875954,"name":"point"},"pe":{"x":693.5,"y":426.2,"name":"point"},"name":"segment"},{"ps":{"x":693.5,"y":426.2,"name":"point"},"pe":{"x":694.8,"y":428.5,"name":"point"},"name":"segment"},{"ps":{"x":694.8,"y":428.5,"name":"point"},"pe":{"x":695.5,"y":432.8,"name":"point"},"name":"segment"},{"ps":{"x":695.5,"y":432.8,"name":"point"},"pe":{"x":698.2,"y":432.8,"name":"point"},"name":"segment"},{"ps":{"x":698.2,"y":432.8,"name":"point"},"pe":{"x":704.9888039661226,"y":423.50026853955796,"name":"point"},"name":"segment"},{"ps":{"x":704.9888039661226,"y":423.50026853955796,"name":"point"},"pe":{"x":707.4083618917066,"y":424.64283755997263,"name":"point"},"name":"segment"},{"ps":{"x":707.4083618917066,"y":424.64283755997263,"name":"point"},"pe":{"x":708,"y":424,"name":"point"},"name":"segment"},{"ps":{"x":708,"y":424,"name":"point"},"pe":{"x":708,"y":424.9222222222223,"name":"point"},"name":"segment"},{"ps":{"x":708,"y":424.9222222222223,"name":"point"},"pe":{"x":708.8,"y":425.3,"name":"point"},"name":"segment"},{"ps":{"x":708.8,"y":425.3,"name":"point"},"pe":{"x":708.1976878612716,"y":429.2150289017341,"name":"point"},"name":"segment"},{"ps":{"x":708.1976878612716,"y":429.2150289017341,"name":"point"},"pe":{"x":707.5,"y":430.2,"name":"point"},"name":"segment"},{"ps":{"x":707.5,"y":430.2,"name":"point"},"pe":{"x":704.5,"y":433.2,"name":"point"},"name":"segment"},{"ps":{"x":704.5,"y":433.2,"name":"point"},"pe":{"x":703.2560975609756,"y":436.060975609756,"name":"point"},"name":"segment"},{"ps":{"x":703.2560975609756,"y":436.060975609756,"name":"point"},"pe":{"x":704.2222222222222,"y":437.8,"name":"point"},"name":"segment"},{"ps":{"x":704.2222222222222,"y":437.8,"name":"point"},"pe":{"x":706.8769230769229,"y":437.8,"name":"point"},"name":"segment"},{"ps":{"x":706.8769230769229,"y":437.8,"name":"point"},"pe":{"x":706.8,"y":438.3,"name":"point"},"name":"segment"},{"ps":{"x":706.8,"y":438.3,"name":"point"},"pe":{"x":709.1390862944162,"y":440.44416243654825,"name":"point"},"name":"segment"},{"ps":{"x":709.1390862944162,"y":440.44416243654825,"name":"point"},"pe":{"x":711.3,"y":441.6,"name":"point"},"name":"segment"},{"ps":{"x":711.3,"y":441.6,"name":"point"},"pe":{"x":714.2224376731302,"y":444.3470914127425,"name":"point"},"name":"segment"},{"ps":{"x":714.2224376731302,"y":444.3470914127425,"name":"point"},"pe":{"x":718.1776978417267,"y":445.86834532374104,"name":"point"},"name":"segment"},{"ps":{"x":718.1776978417267,"y":445.86834532374104,"name":"point"},"pe":{"x":721.853191489362,"y":445.02340425531924,"name":"point"},"name":"segment"},{"ps":{"x":721.853191489362,"y":445.02340425531924,"name":"point"},"pe":{"x":723.3,"y":444.3,"name":"point"},"name":"segment"},{"ps":{"x":723.3,"y":444.3,"name":"point"},"pe":{"x":724.4012145748989,"y":444.4376518218625,"name":"point"},"name":"segment"},{"ps":{"x":724.4012145748989,"y":444.4376518218625,"name":"point"},"pe":{"x":725,"y":444.3,"name":"point"},"name":"segment"},{"ps":{"x":725,"y":444.3,"name":"point"},"pe":{"x":730.3,"y":443.6,"name":"point"},"name":"segment"},{"ps":{"x":730.3,"y":443.6,"name":"point"},"pe":{"x":733.9156521739131,"y":445.62695652173926,"name":"point"},"name":"segment"},{"ps":{"x":733.9156521739131,"y":445.62695652173926,"name":"point"},"pe":{"x":735.3,"y":445.8,"name":"point"},"name":"segment"},{"ps":{"x":735.3,"y":445.8,"name":"point"},"pe":{"x":741.8,"y":445.8,"name":"point"},"name":"segment"},{"ps":{"x":741.8,"y":445.8,"name":"point"},"pe":{"x":742.1687969924812,"y":445.14436090225564,"name":"point"},"name":"segment"},{"ps":{"x":742.1687969924812,"y":445.14436090225564,"name":"point"},"pe":{"x":743.2345314505778,"y":445.62695763799746,"name":"point"},"name":"segment"},{"ps":{"x":743.2345314505778,"y":445.62695763799746,"name":"point"},"pe":{"x":743.3,"y":445.6,"name":"point"},"name":"segment"},{"ps":{"x":743.3,"y":445.6,"name":"point"},"pe":{"x":744.419018404908,"y":445.3901840490798,"name":"point"},"name":"segment"},{"ps":{"x":744.419018404908,"y":445.3901840490798,"name":"point"},"pe":{"x":744.2,"y":443.2,"name":"point"},"name":"segment"},{"ps":{"x":744.2,"y":443.2,"name":"point"},"pe":{"x":743.9540983606557,"y":441.9704918032786,"name":"point"},"name":"segment"},{"ps":{"x":743.9540983606557,"y":441.9704918032786,"name":"point"},"pe":{"x":744.6422857142858,"y":440.7470476190477,"name":"point"},"name":"segment"},{"ps":{"x":744.6422857142858,"y":440.7470476190477,"name":"point"},"pe":{"x":744.6,"y":440,"name":"point"},"name":"segment"},{"ps":{"x":744.6,"y":440,"name":"point"},"pe":{"x":745.6,"y":438.3,"name":"point"},"name":"segment"},{"ps":{"x":745.6,"y":438.3,"name":"point"},"pe":{"x":746.0498233215546,"y":438.24475853945813,"name":"point"},"name":"segment"},{"ps":{"x":746.0498233215546,"y":438.24475853945813,"name":"point"},"pe":{"x":746.3,"y":437.8,"name":"point"},"name":"segment"},{"ps":{"x":746.3,"y":437.8,"name":"point"},"pe":{"x":747.0298969072162,"y":438.1243986254295,"name":"point"},"name":"segment"},{"ps":{"x":747.0298969072162,"y":438.1243986254295,"name":"point"},"pe":{"x":751.3,"y":437.6,"name":"point"},"name":"segment"},{"ps":{"x":751.3,"y":437.6,"name":"point"},"pe":{"x":751.3,"y":439.96666666666664,"name":"point"},"name":"segment"},{"ps":{"x":751.3,"y":439.96666666666664,"name":"point"},"pe":{"x":753.1612903225806,"y":440.5870967741936,"name":"point"},"name":"segment"},{"ps":{"x":753.1612903225806,"y":440.5870967741936,"name":"point"},"pe":{"x":752.8,"y":444.2,"name":"point"},"name":"segment"},{"ps":{"x":752.8,"y":444.2,"name":"point"},"pe":{"x":757.2,"y":446.2,"name":"point"},"name":"segment"},{"ps":{"x":757.2,"y":446.2,"name":"point"},"pe":{"x":758.9810559006212,"y":447.5654761904762,"name":"point"},"name":"segment"},{"ps":{"x":758.9810559006212,"y":447.5654761904762,"name":"point"},"pe":{"x":761.3838747099769,"y":446.5420533642691,"name":"point"},"name":"segment"},{"ps":{"x":761.3838747099769,"y":446.5420533642691,"name":"point"},"pe":{"x":762.8,"y":444.2,"name":"point"},"name":"segment"},{"ps":{"x":762.8,"y":444.2,"name":"point"},"pe":{"x":763.3454545454546,"y":443.9818181818182,"name":"point"},"name":"segment"},{"ps":{"x":763.3454545454546,"y":443.9818181818182,"name":"point"},"pe":{"x":764.3,"y":444.3,"name":"point"},"name":"segment"},{"ps":{"x":764.3,"y":444.3,"name":"point"},"pe":{"x":764.3,"y":445.3,"name":"point"},"name":"segment"},{"ps":{"x":764.3,"y":445.3,"name":"point"},"pe":{"x":765.6,"y":445.3,"name":"point"},"name":"segment"},{"ps":{"x":765.6,"y":445.3,"name":"point"},"pe":{"x":764.9,"y":449,"name":"point"},"name":"segment"},{"ps":{"x":764.9,"y":449,"name":"point"},"pe":{"x":764.6,"y":453.3,"name":"point"},"name":"segment"},{"ps":{"x":764.6,"y":453.3,"name":"point"},"pe":{"x":766.9,"y":454,"name":"point"},"name":"segment"},{"ps":{"x":766.9,"y":454,"name":"point"},"pe":{"x":780.2496868475996,"y":455.45302713987485,"name":"point"},"name":"segment"},{"ps":{"x":780.2496868475996,"y":455.45302713987485,"name":"point"},"pe":{"x":786.8,"y":457.5,"name":"point"},"name":"segment"},{"ps":{"x":786.8,"y":457.5,"name":"point"},"pe":{"x":785.5,"y":458.5,"name":"point"},"name":"segment"},{"ps":{"x":785.5,"y":458.5,"name":"point"},"pe":{"x":782.5,"y":458.5,"name":"point"},"name":"segment"},{"ps":{"x":782.5,"y":458.5,"name":"point"},"pe":{"x":757.1344066237349,"y":460.2519779208832,"name":"point"},"name":"segment"},{"ps":{"x":757.1344066237349,"y":460.2519779208832,"name":"point"},"pe":{"x":748.3,"y":460.6,"name":"point"},"name":"segment"},{"ps":{"x":748.3,"y":460.6,"name":"point"},"pe":{"x":725.3,"y":460.3,"name":"point"},"name":"segment"},{"ps":{"x":725.3,"y":460.3,"name":"point"},"pe":{"x":645.6,"y":462,"name":"point"},"name":"segment"},{"ps":{"x":645.6,"y":462,"name":"point"},"pe":{"x":622.4,"y":462.3,"name":"point"},"name":"segment"},{"ps":{"x":622.4,"y":462.3,"name":"point"},"pe":{"x":605,"y":464.3,"name":"point"},"name":"segment"},{"ps":{"x":605,"y":464.3,"name":"point"},"pe":{"x":567.7751724137913,"y":465.0158620689656,"name":"point"},"name":"segment"},{"ps":{"x":567.7751724137913,"y":465.0158620689656,"name":"point"},"pe":{"x":563.3,"y":465.3,"name":"point"},"name":"segment"},{"ps":{"x":563.3,"y":465.3,"name":"point"},"pe":{"x":524.3033434650456,"y":469.88784194528876,"name":"point"},"name":"segment"},{"ps":{"x":524.3033434650456,"y":469.88784194528876,"name":"point"},"pe":{"x":524.2,"y":469.8,"name":"point"},"name":"segment"},{"ps":{"x":524.2,"y":469.8,"name":"point"},"pe":{"x":520.0857142857142,"y":469.8,"name":"point"},"name":"segment"},{"ps":{"x":520.0857142857142,"y":469.8,"name":"point"},"pe":{"x":515.8,"y":466.8,"name":"point"},"name":"segment"},{"ps":{"x":515.8,"y":466.8,"name":"point"},"pe":{"x":514.7151219512195,"y":466.4609756097562,"name":"point"},"name":"segment"},{"ps":{"x":514.7151219512195,"y":466.4609756097562,"name":"point"},"pe":{"x":514.5186785260483,"y":466.04002541296063,"name":"point"},"name":"segment"},{"ps":{"x":514.5186785260483,"y":466.04002541296063,"name":"point"},"pe":{"x":513.4347826086957,"y":466.0608695652174,"name":"point"},"name":"segment"},{"ps":{"x":513.4347826086957,"y":466.0608695652174,"name":"point"},"pe":{"x":509.7435528500277,"y":464.90736026563366,"name":"point"},"name":"segment"},{"ps":{"x":509.7435528500277,"y":464.90736026563366,"name":"point"},"pe":{"x":508.5535239810852,"y":466.1547399234408,"name":"point"},"name":"segment"},{"ps":{"x":508.5535239810852,"y":466.1547399234408,"name":"point"},"pe":{"x":506.1709497206705,"y":466.2005586592179,"name":"point"},"name":"segment"},{"ps":{"x":506.1709497206705,"y":466.2005586592179,"name":"point"},"pe":{"x":501.8,"y":471.3,"name":"point"},"name":"segment"},{"ps":{"x":501.8,"y":471.3,"name":"point"},"pe":{"x":496.3,"y":470.3,"name":"point"},"name":"segment"},{"ps":{"x":496.3,"y":470.3,"name":"point"},"pe":{"x":491.8,"y":476.8,"name":"point"},"name":"segment"},{"ps":{"x":491.8,"y":476.8,"name":"point"},"pe":{"x":487.24683544303804,"y":480.52531645569616,"name":"point"},"name":"segment"},{"ps":{"x":487.24683544303804,"y":480.52531645569616,"name":"point"},"pe":{"x":485.39595375722547,"y":480.7104046242774,"name":"point"},"name":"segment"},{"ps":{"x":485.39595375722547,"y":480.7104046242774,"name":"point"},"pe":{"x":474.8,"y":473.8,"name":"point"},"name":"segment"},{"ps":{"x":474.8,"y":473.8,"name":"point"},"pe":{"x":493.8,"y":460.3,"name":"point"},"name":"segment"},{"ps":{"x":493.8,"y":460.3,"name":"point"},"pe":{"x":489.8,"y":454.8,"name":"point"},"name":"segment"},{"ps":{"x":489.8,"y":454.8,"name":"point"},"pe":{"x":490.286346300534,"y":453.2193745232649,"name":"point"},"name":"segment"},{"ps":{"x":490.286346300534,"y":453.2193745232649,"name":"point"},"pe":{"x":489.3,"y":451.6,"name":"point"},"name":"segment"},{"ps":{"x":489.3,"y":451.6,"name":"point"},"pe":{"x":491.0807980049874,"y":450.63740648379087,"name":"point"},"name":"segment"},{"ps":{"x":491.0807980049874,"y":450.63740648379087,"name":"point"},"pe":{"x":491.7792207792208,"y":448.36753246753244,"name":"point"},"name":"segment"},{"ps":{"x":491.7792207792208,"y":448.36753246753244,"name":"point"},"pe":{"x":492.5,"y":448.8,"name":"point"},"name":"segment"},{"ps":{"x":492.5,"y":448.8,"name":"point"},"pe":{"x":495.6999999999999,"y":449.6,"name":"point"},"name":"segment"}],[{"ps":{"x":611.372463768116,"y":427.6623188405795,"name":"point"},"pe":{"x":612.7571428571428,"y":425.9,"name":"point"},"name":"segment"},{"ps":{"x":612.7571428571428,"y":425.9,"name":"point"},"pe":{"x":612.3,"y":425.9,"name":"point"},"name":"segment"},{"ps":{"x":612.3,"y":425.9,"name":"point"},"pe":{"x":611.372463768116,"y":427.6623188405795,"name":"point"},"name":"segment"}],[{"ps":{"x":565,"y":434.8,"name":"point"},"pe":{"x":565.7,"y":434.8,"name":"point"},"name":"segment"},{"ps":{"x":565.7,"y":434.8,"name":"point"},"pe":{"x":565.5,"y":434.7,"name":"point"},"name":"segment"},{"ps":{"x":565.5,"y":434.7,"name":"point"},"pe":{"x":565,"y":434.8,"name":"point"},"name":"segment"}]]`;
            const json2 = `[[{"ps":{"x":495.6999999999999,"y":449.6,"name":"point"},"pe":{"x":496.5,"y":449.8,"name":"point"},"name":"segment"},{"ps":{"x":496.5,"y":449.8,"name":"point"},"pe":{"x":497.8,"y":451.2,"name":"point"},"name":"segment"},{"ps":{"x":497.8,"y":451.2,"name":"point"},"pe":{"x":500.62352941176465,"y":449.6,"name":"point"},"name":"segment"},{"ps":{"x":500.62352941176465,"y":449.6,"name":"point"},"pe":{"x":504.3,"y":449.6,"name":"point"},"name":"segment"},{"ps":{"x":504.3,"y":449.6,"name":"point"},"pe":{"x":509.7,"y":448.3,"name":"point"},"name":"segment"},{"ps":{"x":509.7,"y":448.3,"name":"point"},"pe":{"x":510.16305569749636,"y":447.76647930505874,"name":"point"},"name":"segment"},{"ps":{"x":510.16305569749636,"y":447.76647930505874,"name":"point"},"pe":{"x":511.8,"y":447.5,"name":"point"},"name":"segment"},{"ps":{"x":511.8,"y":447.5,"name":"point"},"pe":{"x":512.0000000000002,"y":445.64999999999986,"name":"point"},"name":"segment"},{"ps":{"x":512.0000000000002,"y":445.64999999999986,"name":"point"},"pe":{"x":514.3,"y":443,"name":"point"},"name":"segment"},{"ps":{"x":514.3,"y":443,"name":"point"},"pe":{"x":522.3,"y":427.6,"name":"point"},"name":"segment"},{"ps":{"x":522.3,"y":427.6,"name":"point"},"pe":{"x":525,"y":426,"name":"point"},"name":"segment"},{"ps":{"x":525,"y":426,"name":"point"},"pe":{"x":527,"y":419.6,"name":"point"},"name":"segment"},{"ps":{"x":527,"y":419.6,"name":"point"},"pe":{"x":536.3,"y":419.3,"name":"point"},"name":"segment"},{"ps":{"x":536.3,"y":419.3,"name":"point"},"pe":{"x":536.3,"y":420.3,"name":"point"},"name":"segment"},{"ps":{"x":536.3,"y":420.3,"name":"point"},"pe":{"x":535.7,"y":421.6,"name":"point"},"name":"segment"},{"ps":{"x":535.7,"y":421.6,"name":"point"},"pe":{"x":533,"y":425.3,"name":"point"},"name":"segment"},{"ps":{"x":533,"y":425.3,"name":"point"},"pe":{"x":533,"y":431,"name":"point"},"name":"segment"},{"ps":{"x":533,"y":431,"name":"point"},"pe":{"x":531.7,"y":433.6,"name":"point"},"name":"segment"},{"ps":{"x":531.7,"y":433.6,"name":"point"},"pe":{"x":533.3,"y":438.6,"name":"point"},"name":"segment"},{"ps":{"x":533.3,"y":438.6,"name":"point"},"pe":{"x":534.74578313253,"y":439.0915662650602,"name":"point"},"name":"segment"},{"ps":{"x":534.74578313253,"y":439.0915662650602,"name":"point"},"pe":{"x":534.8,"y":439.2,"name":"point"},"name":"segment"},{"ps":{"x":534.8,"y":439.2,"name":"point"},"pe":{"x":534.9610738255034,"y":439.1647651006711,"name":"point"},"name":"segment"},{"ps":{"x":534.9610738255034,"y":439.1647651006711,"name":"point"},"pe":{"x":538.3,"y":440.3,"name":"point"},"name":"segment"},{"ps":{"x":538.3,"y":440.3,"name":"point"},"pe":{"x":547.1,"y":439.6,"name":"point"},"name":"segment"},{"ps":{"x":547.1,"y":439.6,"name":"point"},"pe":{"x":550.9,"y":438,"name":"point"},"name":"segment"},{"ps":{"x":550.9,"y":438,"name":"point"},"pe":{"x":549.7,"y":438.3,"name":"point"},"name":"segment"},{"ps":{"x":549.7,"y":438.3,"name":"point"},"pe":{"x":553,"y":435.6,"name":"point"},"name":"segment"},{"ps":{"x":553,"y":435.6,"name":"point"},"pe":{"x":557.7,"y":435.6,"name":"point"},"name":"segment"},{"ps":{"x":557.7,"y":435.6,"name":"point"},"pe":{"x":559.7,"y":432.6,"name":"point"},"name":"segment"},{"ps":{"x":559.7,"y":432.6,"name":"point"},"pe":{"x":561.3,"y":432.6,"name":"point"},"name":"segment"},{"ps":{"x":561.3,"y":432.6,"name":"point"},"pe":{"x":563.7,"y":433.6,"name":"point"},"name":"segment"},{"ps":{"x":563.7,"y":433.6,"name":"point"},"pe":{"x":565.5,"y":434.7,"name":"point"},"name":"segment"},{"ps":{"x":565.5,"y":434.7,"name":"point"},"pe":{"x":566.6864516129033,"y":434.43634408602156,"name":"point"},"name":"segment"},{"ps":{"x":566.6864516129033,"y":434.43634408602156,"name":"point"},"pe":{"x":566.8,"y":434.5,"name":"point"},"name":"segment"},{"ps":{"x":566.8,"y":434.5,"name":"point"},"pe":{"x":566.8888888888888,"y":434.3913580246913,"name":"point"},"name":"segment"},{"ps":{"x":566.8888888888888,"y":434.3913580246913,"name":"point"},"pe":{"x":570,"y":433.7,"name":"point"},"name":"segment"},{"ps":{"x":570,"y":433.7,"name":"point"},"pe":{"x":571.7,"y":431.6,"name":"point"},"name":"segment"},{"ps":{"x":571.7,"y":431.6,"name":"point"},"pe":{"x":572.3,"y":427,"name":"point"},"name":"segment"},{"ps":{"x":572.3,"y":427,"name":"point"},"pe":{"x":571,"y":422,"name":"point"},"name":"segment"},{"ps":{"x":571,"y":422,"name":"point"},"pe":{"x":571.7,"y":419.6,"name":"point"},"name":"segment"},{"ps":{"x":571.7,"y":419.6,"name":"point"},"pe":{"x":574.7,"y":419,"name":"point"},"name":"segment"},{"ps":{"x":574.7,"y":419,"name":"point"},"pe":{"x":575.7,"y":420,"name":"point"},"name":"segment"},{"ps":{"x":575.7,"y":420,"name":"point"},"pe":{"x":578,"y":426.3,"name":"point"},"name":"segment"},{"ps":{"x":578,"y":426.3,"name":"point"},"pe":{"x":580.3,"y":426.3,"name":"point"},"name":"segment"},{"ps":{"x":580.3,"y":426.3,"name":"point"},"pe":{"x":586.3,"y":423.3,"name":"point"},"name":"segment"},{"ps":{"x":586.3,"y":423.3,"name":"point"},"pe":{"x":594.3,"y":420.3,"name":"point"},"name":"segment"},{"ps":{"x":594.3,"y":420.3,"name":"point"},"pe":{"x":596.6,"y":423,"name":"point"},"name":"segment"},{"ps":{"x":596.6,"y":423,"name":"point"},"pe":{"x":596.7947261663286,"y":423.03245436105476,"name":"point"},"name":"segment"},{"ps":{"x":596.7947261663286,"y":423.03245436105476,"name":"point"},"pe":{"x":593.5,"y":429.8,"name":"point"},"name":"segment"},{"ps":{"x":593.5,"y":429.8,"name":"point"},"pe":{"x":595.5,"y":435.5,"name":"point"},"name":"segment"},{"ps":{"x":595.5,"y":435.5,"name":"point"},"pe":{"x":596.2,"y":438.2,"name":"point"},"name":"segment"},{"ps":{"x":596.2,"y":438.2,"name":"point"},"pe":{"x":598.8,"y":437.8,"name":"point"},"name":"segment"},{"ps":{"x":598.8,"y":437.8,"name":"point"},"pe":{"x":600.5,"y":435.5,"name":"point"},"name":"segment"},{"ps":{"x":600.5,"y":435.5,"name":"point"},"pe":{"x":602.8,"y":429.5,"name":"point"},"name":"segment"},{"ps":{"x":602.8,"y":429.5,"name":"point"},"pe":{"x":602.2,"y":427.8,"name":"point"},"name":"segment"},{"ps":{"x":602.2,"y":427.8,"name":"point"},"pe":{"x":602.2,"y":425.5,"name":"point"},"name":"segment"},{"ps":{"x":602.2,"y":425.5,"name":"point"},"pe":{"x":602.7065743944636,"y":424.0647058823528,"name":"point"},"name":"segment"},{"ps":{"x":602.7065743944636,"y":424.0647058823528,"name":"point"},"pe":{"x":605.4,"y":425.7,"name":"point"},"name":"segment"},{"ps":{"x":605.4,"y":425.7,"name":"point"},"pe":{"x":604.8,"y":425.8,"name":"point"},"name":"segment"},{"ps":{"x":604.8,"y":425.8,"name":"point"},"pe":{"x":606.4,"y":426.5,"name":"point"},"name":"segment"},{"ps":{"x":606.4,"y":426.5,"name":"point"},"pe":{"x":605.6,"y":426,"name":"point"},"name":"segment"},{"ps":{"x":605.6,"y":426,"name":"point"},"pe":{"x":607.4349083895853,"y":425.97261330761813,"name":"point"},"name":"segment"},{"ps":{"x":607.4349083895853,"y":425.97261330761813,"name":"point"},"pe":{"x":609.2,"y":426.8,"name":"point"},"name":"segment"},{"ps":{"x":609.2,"y":426.8,"name":"point"},"pe":{"x":609.8233025984912,"y":425.93696563285835,"name":"point"},"name":"segment"},{"ps":{"x":609.8233025984912,"y":425.93696563285835,"name":"point"},"pe":{"x":612.3,"y":425.9,"name":"point"},"name":"segment"},{"ps":{"x":612.3,"y":425.9,"name":"point"},"pe":{"x":613.3,"y":424,"name":"point"},"name":"segment"},{"ps":{"x":613.3,"y":424,"name":"point"},"pe":{"x":615.3,"y":423.3,"name":"point"},"name":"segment"},{"ps":{"x":615.3,"y":423.3,"name":"point"},"pe":{"x":620,"y":424,"name":"point"},"name":"segment"},{"ps":{"x":620,"y":424,"name":"point"},"pe":{"x":623.3,"y":421.6,"name":"point"},"name":"segment"},{"ps":{"x":623.3,"y":421.6,"name":"point"},"pe":{"x":627,"y":417,"name":"point"},"name":"segment"},{"ps":{"x":627,"y":417,"name":"point"},"pe":{"x":629.4144013880857,"y":407.708212839792,"name":"point"},"name":"segment"},{"ps":{"x":629.4144013880857,"y":407.708212839792,"name":"point"},"pe":{"x":629.5,"y":407.5,"name":"point"},"name":"segment"},{"ps":{"x":629.5,"y":407.5,"name":"point"},"pe":{"x":629.4893858984078,"y":407.4196360879452,"name":"point"},"name":"segment"},{"ps":{"x":629.4893858984078,"y":407.4196360879452,"name":"point"},"pe":{"x":630.3,"y":404.3,"name":"point"},"name":"segment"},{"ps":{"x":630.3,"y":404.3,"name":"point"},"pe":{"x":633.3,"y":397,"name":"point"},"name":"segment"},{"ps":{"x":633.3,"y":397,"name":"point"},"pe":{"x":635.3,"y":396.6,"name":"point"},"name":"segment"},{"ps":{"x":635.3,"y":396.6,"name":"point"},"pe":{"x":636.6,"y":402,"name":"point"},"name":"segment"},{"ps":{"x":636.6,"y":402,"name":"point"},"pe":{"x":637.6,"y":411,"name":"point"},"name":"segment"},{"ps":{"x":637.6,"y":411,"name":"point"},"pe":{"x":651,"y":407.6,"name":"point"},"name":"segment"},{"ps":{"x":651,"y":407.6,"name":"point"},"pe":{"x":652.6,"y":409.3,"name":"point"},"name":"segment"},{"ps":{"x":652.6,"y":409.3,"name":"point"},"pe":{"x":653.8589003054707,"y":411.9902527075812,"name":"point"},"name":"segment"},{"ps":{"x":653.8589003054707,"y":411.9902527075812,"name":"point"},"pe":{"x":652.8,"y":412.8,"name":"point"},"name":"segment"},{"ps":{"x":652.8,"y":412.8,"name":"point"},"pe":{"x":650.2,"y":412.8,"name":"point"},"name":"segment"},{"ps":{"x":650.2,"y":412.8,"name":"point"},"pe":{"x":637.5,"y":415.5,"name":"point"},"name":"segment"},{"ps":{"x":637.5,"y":415.5,"name":"point"},"pe":{"x":631.8,"y":418.2,"name":"point"},"name":"segment"},{"ps":{"x":631.8,"y":418.2,"name":"point"},"pe":{"x":624.8,"y":426.2,"name":"point"},"name":"segment"},{"ps":{"x":624.8,"y":426.2,"name":"point"},"pe":{"x":622.2,"y":428.2,"name":"point"},"name":"segment"},{"ps":{"x":622.2,"y":428.2,"name":"point"},"pe":{"x":620.5,"y":430.2,"name":"point"},"name":"segment"},{"ps":{"x":620.5,"y":430.2,"name":"point"},"pe":{"x":617.8,"y":432.5,"name":"point"},"name":"segment"},{"ps":{"x":617.8,"y":432.5,"name":"point"},"pe":{"x":614.5,"y":435.8,"name":"point"},"name":"segment"},{"ps":{"x":614.5,"y":435.8,"name":"point"},"pe":{"x":619.5,"y":435.8,"name":"point"},"name":"segment"},{"ps":{"x":619.5,"y":435.8,"name":"point"},"pe":{"x":621.5,"y":437.5,"name":"point"},"name":"segment"},{"ps":{"x":621.5,"y":437.5,"name":"point"},"pe":{"x":624.5,"y":440.8,"name":"point"},"name":"segment"},{"ps":{"x":624.5,"y":440.8,"name":"point"},"pe":{"x":627.2,"y":440.8,"name":"point"},"name":"segment"},{"ps":{"x":627.2,"y":440.8,"name":"point"},"pe":{"x":629.5,"y":439.2,"name":"point"},"name":"segment"},{"ps":{"x":629.5,"y":439.2,"name":"point"},"pe":{"x":631.5,"y":438.8,"name":"point"},"name":"segment"},{"ps":{"x":631.5,"y":438.8,"name":"point"},"pe":{"x":633.8,"y":439.5,"name":"point"},"name":"segment"},{"ps":{"x":633.8,"y":439.5,"name":"point"},"pe":{"x":635.2,"y":442.5,"name":"point"},"name":"segment"},{"ps":{"x":635.2,"y":442.5,"name":"point"},"pe":{"x":638.8,"y":445.2,"name":"point"},"name":"segment"},{"ps":{"x":638.8,"y":445.2,"name":"point"},"pe":{"x":642.8,"y":445.2,"name":"point"},"name":"segment"},{"ps":{"x":642.8,"y":445.2,"name":"point"},"pe":{"x":645.8,"y":444.2,"name":"point"},"name":"segment"},{"ps":{"x":645.8,"y":444.2,"name":"point"},"pe":{"x":649.5,"y":443.8,"name":"point"},"name":"segment"},{"ps":{"x":649.5,"y":443.8,"name":"point"},"pe":{"x":654.2,"y":432.8,"name":"point"},"name":"segment"},{"ps":{"x":654.2,"y":432.8,"name":"point"},"pe":{"x":654.2,"y":429.8,"name":"point"},"name":"segment"},{"ps":{"x":654.2,"y":429.8,"name":"point"},"pe":{"x":658.2,"y":426.2,"name":"point"},"name":"segment"},{"ps":{"x":658.2,"y":426.2,"name":"point"},"pe":{"x":660.2,"y":425.8,"name":"point"},"name":"segment"},{"ps":{"x":660.2,"y":425.8,"name":"point"},"pe":{"x":660.95,"y":425.95,"name":"point"},"name":"segment"},{"ps":{"x":660.95,"y":425.95,"name":"point"},"pe":{"x":662.6285714285714,"y":427.62857142857126,"name":"point"},"name":"segment"},{"ps":{"x":662.6285714285714,"y":427.62857142857126,"name":"point"},"pe":{"x":662.8,"y":428.2,"name":"point"},"name":"segment"},{"ps":{"x":662.8,"y":428.2,"name":"point"},"pe":{"x":662.8,"y":430.5,"name":"point"},"name":"segment"},{"ps":{"x":662.8,"y":430.5,"name":"point"},"pe":{"x":658.8,"y":433.5,"name":"point"},"name":"segment"},{"ps":{"x":658.8,"y":433.5,"name":"point"},"pe":{"x":656.2,"y":443.2,"name":"point"},"name":"segment"},{"ps":{"x":656.2,"y":443.2,"name":"point"},"pe":{"x":664.2,"y":443.2,"name":"point"},"name":"segment"},{"ps":{"x":664.2,"y":443.2,"name":"point"},"pe":{"x":669.2,"y":441.8,"name":"point"},"name":"segment"},{"ps":{"x":669.2,"y":441.8,"name":"point"},"pe":{"x":672.5,"y":438.8,"name":"point"},"name":"segment"},{"ps":{"x":672.5,"y":438.8,"name":"point"},"pe":{"x":676.5,"y":430.8,"name":"point"},"name":"segment"},{"ps":{"x":676.5,"y":430.8,"name":"point"},"pe":{"x":676.9880421243348,"y":424.8040539010306,"name":"point"},"name":"segment"},{"ps":{"x":676.9880421243348,"y":424.8040539010306,"name":"point"},"pe":{"x":677.4,"y":424.6,"name":"point"},"name":"segment"},{"ps":{"x":677.4,"y":424.6,"name":"point"},"pe":{"x":677.0046511627908,"y":424.6,"name":"point"},"name":"segment"},{"ps":{"x":677.0046511627908,"y":424.6,"name":"point"},"pe":{"x":677.0326693227092,"y":424.2557768924303,"name":"point"},"name":"segment"},{"ps":{"x":677.0326693227092,"y":424.2557768924303,"name":"point"},"pe":{"x":679,"y":423.6,"name":"point"},"name":"segment"},{"ps":{"x":679,"y":423.6,"name":"point"},"pe":{"x":682.357482185273,"y":421.67707838479805,"name":"point"},"name":"segment"},{"ps":{"x":682.357482185273,"y":421.67707838479805,"name":"point"},"pe":{"x":682.8,"y":421.8,"name":"point"},"name":"segment"},{"ps":{"x":682.8,"y":421.8,"name":"point"},"pe":{"x":683.8,"y":426.2,"name":"point"},"name":"segment"},{"ps":{"x":683.8,"y":426.2,"name":"point"},"pe":{"x":685.5,"y":426.2,"name":"point"},"name":"segment"},{"ps":{"x":685.5,"y":426.2,"name":"point"},"pe":{"x":687.2,"y":424.8,"name":"point"},"name":"segment"},{"ps":{"x":687.2,"y":424.8,"name":"point"},"pe":{"x":687.6086956521738,"y":418.66956521739127,"name":"point"},"name":"segment"},{"ps":{"x":687.6086956521738,"y":418.66956521739127,"name":"point"},"pe":{"x":690,"y":417.3,"name":"point"},"name":"segment"},{"ps":{"x":690,"y":417.3,"name":"point"},"pe":{"x":691.3,"y":418.6,"name":"point"},"name":"segment"},{"ps":{"x":691.3,"y":418.6,"name":"point"},"pe":{"x":692.1,"y":424.3,"name":"point"},"name":"segment"},{"ps":{"x":692.1,"y":424.3,"name":"point"},"pe":{"x":691.8,"y":424.3,"name":"point"},"name":"segment"},{"ps":{"x":691.8,"y":424.3,"name":"point"},"pe":{"x":692.6,"y":425.3,"name":"point"},"name":"segment"},{"ps":{"x":692.6,"y":425.3,"name":"point"},"pe":{"x":694.3,"y":433.6,"name":"point"},"name":"segment"},{"ps":{"x":694.3,"y":433.6,"name":"point"},"pe":{"x":697.6,"y":435.3,"name":"point"},"name":"segment"},{"ps":{"x":697.6,"y":435.3,"name":"point"},"pe":{"x":708,"y":424,"name":"point"},"name":"segment"},{"ps":{"x":708,"y":424,"name":"point"},"pe":{"x":708,"y":426.3,"name":"point"},"name":"segment"},{"ps":{"x":708,"y":426.3,"name":"point"},"pe":{"x":703,"y":435.6,"name":"point"},"name":"segment"},{"ps":{"x":703,"y":435.6,"name":"point"},"pe":{"x":703.2560975609756,"y":436.060975609756,"name":"point"},"name":"segment"},{"ps":{"x":703.2560975609756,"y":436.060975609756,"name":"point"},"pe":{"x":702.5,"y":437.8,"name":"point"},"name":"segment"},{"ps":{"x":702.5,"y":437.8,"name":"point"},"pe":{"x":704.2222222222222,"y":437.8,"name":"point"},"name":"segment"},{"ps":{"x":704.2222222222222,"y":437.8,"name":"point"},"pe":{"x":704.5,"y":438.3,"name":"point"},"name":"segment"},{"ps":{"x":704.5,"y":438.3,"name":"point"},"pe":{"x":707,"y":439.3,"name":"point"},"name":"segment"},{"ps":{"x":707,"y":439.3,"name":"point"},"pe":{"x":711.3,"y":441.6,"name":"point"},"name":"segment"},{"ps":{"x":711.3,"y":441.6,"name":"point"},"pe":{"x":716.3,"y":446.3,"name":"point"},"name":"segment"},{"ps":{"x":716.3,"y":446.3,"name":"point"},"pe":{"x":725,"y":444.3,"name":"point"},"name":"segment"},{"ps":{"x":725,"y":444.3,"name":"point"},"pe":{"x":730.3,"y":443.6,"name":"point"},"name":"segment"},{"ps":{"x":730.3,"y":443.6,"name":"point"},"pe":{"x":736.9,"y":447.3,"name":"point"},"name":"segment"},{"ps":{"x":736.9,"y":447.3,"name":"point"},"pe":{"x":739.9,"y":447,"name":"point"},"name":"segment"},{"ps":{"x":739.9,"y":447,"name":"point"},"pe":{"x":743.2345314505777,"y":445.62695763799746,"name":"point"},"name":"segment"},{"ps":{"x":743.2345314505777,"y":445.62695763799746,"name":"point"},"pe":{"x":744.5,"y":446.2,"name":"point"},"name":"segment"},{"ps":{"x":744.5,"y":446.2,"name":"point"},"pe":{"x":744.419018404908,"y":445.3901840490798,"name":"point"},"name":"segment"},{"ps":{"x":744.419018404908,"y":445.3901840490798,"name":"point"},"pe":{"x":744.9,"y":445.3,"name":"point"},"name":"segment"},{"ps":{"x":744.9,"y":445.3,"name":"point"},"pe":{"x":744.6,"y":440,"name":"point"},"name":"segment"},{"ps":{"x":744.6,"y":440,"name":"point"},"pe":{"x":745.6,"y":438.3,"name":"point"},"name":"segment"},{"ps":{"x":745.6,"y":438.3,"name":"point"},"pe":{"x":751.3,"y":437.6,"name":"point"},"name":"segment"},{"ps":{"x":751.3,"y":437.6,"name":"point"},"pe":{"x":751.3,"y":446,"name":"point"},"name":"segment"},{"ps":{"x":751.3,"y":446,"name":"point"},"pe":{"x":758.9,"y":447.6,"name":"point"},"name":"segment"},{"ps":{"x":758.9,"y":447.6,"name":"point"},"pe":{"x":758.9810559006212,"y":447.5654761904762,"name":"point"},"name":"segment"},{"ps":{"x":758.9810559006212,"y":447.5654761904762,"name":"point"},"pe":{"x":760.2,"y":448.5,"name":"point"},"name":"segment"},{"ps":{"x":760.2,"y":448.5,"name":"point"},"pe":{"x":761.3838747099769,"y":446.5420533642691,"name":"point"},"name":"segment"},{"ps":{"x":761.3838747099769,"y":446.5420533642691,"name":"point"},"pe":{"x":764.3,"y":445.3,"name":"point"},"name":"segment"},{"ps":{"x":764.3,"y":445.3,"name":"point"},"pe":{"x":765.6,"y":445.3,"name":"point"},"name":"segment"},{"ps":{"x":765.6,"y":445.3,"name":"point"},"pe":{"x":764.9,"y":449,"name":"point"},"name":"segment"},{"ps":{"x":764.9,"y":449,"name":"point"},"pe":{"x":764.6,"y":453.3,"name":"point"},"name":"segment"},{"ps":{"x":764.6,"y":453.3,"name":"point"},"pe":{"x":766.9,"y":454,"name":"point"},"name":"segment"},{"ps":{"x":766.9,"y":454,"name":"point"},"pe":{"x":780.2496868475996,"y":455.45302713987485,"name":"point"},"name":"segment"},{"ps":{"x":780.2496868475996,"y":455.45302713987485,"name":"point"},"pe":{"x":786.8,"y":457.5,"name":"point"},"name":"segment"},{"ps":{"x":786.8,"y":457.5,"name":"point"},"pe":{"x":785.5,"y":458.5,"name":"point"},"name":"segment"},{"ps":{"x":785.5,"y":458.5,"name":"point"},"pe":{"x":782.5,"y":458.5,"name":"point"},"name":"segment"},{"ps":{"x":782.5,"y":458.5,"name":"point"},"pe":{"x":757.1344066237349,"y":460.2519779208832,"name":"point"},"name":"segment"},{"ps":{"x":757.1344066237349,"y":460.2519779208832,"name":"point"},"pe":{"x":748.3,"y":460.6,"name":"point"},"name":"segment"},{"ps":{"x":748.3,"y":460.6,"name":"point"},"pe":{"x":725.3,"y":460.3,"name":"point"},"name":"segment"},{"ps":{"x":725.3,"y":460.3,"name":"point"},"pe":{"x":645.6,"y":462,"name":"point"},"name":"segment"},{"ps":{"x":645.6,"y":462,"name":"point"},"pe":{"x":622.4,"y":462.3,"name":"point"},"name":"segment"},{"ps":{"x":622.4,"y":462.3,"name":"point"},"pe":{"x":605,"y":464.3,"name":"point"},"name":"segment"},{"ps":{"x":605,"y":464.3,"name":"point"},"pe":{"x":514.5186785260482,"y":466.0400254129607,"name":"point"},"name":"segment"},{"ps":{"x":514.5186785260482,"y":466.0400254129607,"name":"point"},"pe":{"x":513.8,"y":464.5,"name":"point"},"name":"segment"},{"ps":{"x":513.8,"y":464.5,"name":"point"},"pe":{"x":512.2,"y":463.5,"name":"point"},"name":"segment"},{"ps":{"x":512.2,"y":463.5,"name":"point"},"pe":{"x":510.8,"y":463.8,"name":"point"},"name":"segment"},{"ps":{"x":510.8,"y":463.8,"name":"point"},"pe":{"x":508.5535239810852,"y":466.1547399234408,"name":"point"},"name":"segment"},{"ps":{"x":508.5535239810852,"y":466.1547399234408,"name":"point"},"pe":{"x":501,"y":466.3,"name":"point"},"name":"segment"},{"ps":{"x":501,"y":466.3,"name":"point"},"pe":{"x":487,"y":467.6,"name":"point"},"name":"segment"},{"ps":{"x":487,"y":467.6,"name":"point"},"pe":{"x":496,"y":462.6,"name":"point"},"name":"segment"},{"ps":{"x":496,"y":462.6,"name":"point"},"pe":{"x":489.3,"y":451.6,"name":"point"},"name":"segment"},{"ps":{"x":489.3,"y":451.6,"name":"point"},"pe":{"x":493,"y":449.6,"name":"point"},"name":"segment"},{"ps":{"x":493,"y":449.6,"name":"point"},"pe":{"x":495.6999999999999,"y":449.6,"name":"point"},"name":"segment"}],[{"ps":{"x":611.3,"y":427.8,"name":"point"},"pe":{"x":612.3,"y":427.3,"name":"point"},"name":"segment"},{"ps":{"x":612.3,"y":427.3,"name":"point"},"pe":{"x":613.4,"y":425.9,"name":"point"},"name":"segment"},{"ps":{"x":613.4,"y":425.9,"name":"point"},"pe":{"x":612.3,"y":425.9,"name":"point"},"name":"segment"},{"ps":{"x":612.3,"y":425.9,"name":"point"},"pe":{"x":611.3,"y":427.8,"name":"point"},"name":"segment"}],[{"ps":{"x":569.9,"y":433.9,"name":"point"},"pe":{"x":574,"y":432.8,"name":"point"},"name":"segment"},{"ps":{"x":574,"y":432.8,"name":"point"},"pe":{"x":570,"y":433.7,"name":"point"},"name":"segment"},{"ps":{"x":570,"y":433.7,"name":"point"},"pe":{"x":569.9,"y":433.9,"name":"point"},"name":"segment"}],[{"ps":{"x":565,"y":434.8,"name":"point"},"pe":{"x":565.7,"y":434.8,"name":"point"},"name":"segment"},{"ps":{"x":565.7,"y":434.8,"name":"point"},"pe":{"x":565.5,"y":434.7,"name":"point"},"name":"segment"},{"ps":{"x":565.5,"y":434.7,"name":"point"},"pe":{"x":565,"y":434.8,"name":"point"},"name":"segment"}]]`;

            // const json1 = `[[{"ps":{"x":495.6999999999999,"y":449.6,"name":"point"},"pe":{"x":500.62352941176465,"y":449.6,"name":"point"},"name":"segment"},{"ps":{"x":500.62352941176465,"y":449.6,"name":"point"},"pe":{"x":500.8,"y":449.5,"name":"point"},"name":"segment"},{"ps":{"x":500.8,"y":449.5,"name":"point"},"pe":{"x":501.6222222222222,"y":448.67777777777775,"name":"point"},"name":"segment"},{"ps":{"x":501.6222222222222,"y":448.67777777777775,"name":"point"},"pe":{"x":504.8,"y":448.8,"name":"point"},"name":"segment"},{"ps":{"x":504.8,"y":448.8,"name":"point"},"pe":{"x":507.11999999999995,"y":448.21999999999997,"name":"point"},"name":"segment"},{"ps":{"x":507.11999999999995,"y":448.21999999999997,"name":"point"},"pe":{"x":507.5,"y":448.2,"name":"point"},"name":"segment"},{"ps":{"x":507.5,"y":448.2,"name":"point"},"pe":{"x":510.16305569749636,"y":447.76647930505874,"name":"point"},"name":"segment"},{"ps":{"x":510.16305569749636,"y":447.76647930505874,"name":"point"},"pe":{"x":512.0000000000002,"y":445.64999999999986,"name":"point"},"name":"segment"},{"ps":{"x":512.0000000000002,"y":445.64999999999986,"name":"point"},"pe":{"x":512.2,"y":443.8,"name":"point"},"name":"segment"},{"ps":{"x":512.2,"y":443.8,"name":"point"},"pe":{"x":512.4352941176471,"y":442.9529411764702,"name":"point"},"name":"segment"},{"ps":{"x":512.4352941176471,"y":442.9529411764702,"name":"point"},"pe":{"x":513.3,"y":441.8,"name":"point"},"name":"segment"},{"ps":{"x":513.3,"y":441.8,"name":"point"},"pe":{"x":515.0562499999997,"y":438.2875000000002,"name":"point"},"name":"segment"},{"ps":{"x":515.0562499999997,"y":438.2875000000002,"name":"point"},"pe":{"x":516.5,"y":436.8,"name":"point"},"name":"segment"},{"ps":{"x":516.5,"y":436.8,"name":"point"},"pe":{"x":516.5893617021277,"y":435.22127659574465,"name":"point"},"name":"segment"},{"ps":{"x":516.5893617021277,"y":435.22127659574465,"name":"point"},"pe":{"x":519.8,"y":428.8,"name":"point"},"name":"segment"},{"ps":{"x":519.8,"y":428.8,"name":"point"},"pe":{"x":521.3303326810178,"y":426.90958904109596,"name":"point"},"name":"segment"},{"ps":{"x":521.3303326810178,"y":426.90958904109596,"name":"point"},"pe":{"x":521.8,"y":426.8,"name":"point"},"name":"segment"},{"ps":{"x":521.8,"y":426.8,"name":"point"},"pe":{"x":523.5,"y":426.8,"name":"point"},"name":"segment"},{"ps":{"x":523.5,"y":426.8,"name":"point"},"pe":{"x":524.4297872340426,"y":423.08085106382975,"name":"point"},"name":"segment"},{"ps":{"x":524.4297872340426,"y":423.08085106382975,"name":"point"},"pe":{"x":526.8443113772455,"y":420.0982035928144,"name":"point"},"name":"segment"},{"ps":{"x":526.8443113772455,"y":420.0982035928144,"name":"point"},"pe":{"x":527,"y":419.6,"name":"point"},"name":"segment"},{"ps":{"x":527,"y":419.6,"name":"point"},"pe":{"x":527.254258675079,"y":419.5917981072555,"name":"point"},"name":"segment"},{"ps":{"x":527.254258675079,"y":419.5917981072555,"name":"point"},"pe":{"x":528.3,"y":418.3,"name":"point"},"name":"segment"},{"ps":{"x":528.3,"y":418.3,"name":"point"},"pe":{"x":536.9370833333332,"y":418.7545833333333,"name":"point"},"name":"segment"},{"ps":{"x":536.9370833333332,"y":418.7545833333333,"name":"point"},"pe":{"x":537.4696969696968,"y":419.7437229437229,"name":"point"},"name":"segment"},{"ps":{"x":537.4696969696968,"y":419.7437229437229,"name":"point"},"pe":{"x":536.273933649289,"y":423.1601895734599,"name":"point"},"name":"segment"},{"ps":{"x":536.273933649289,"y":423.1601895734599,"name":"point"},"pe":{"x":536.2,"y":423.2,"name":"point"},"name":"segment"},{"ps":{"x":536.2,"y":423.2,"name":"point"},"pe":{"x":534.5,"y":425.5,"name":"point"},"name":"segment"},{"ps":{"x":534.5,"y":425.5,"name":"point"},"pe":{"x":534.2,"y":428.2,"name":"point"},"name":"segment"},{"ps":{"x":534.2,"y":428.2,"name":"point"},"pe":{"x":534.2,"y":428.94999999999993,"name":"point"},"name":"segment"},{"ps":{"x":534.2,"y":428.94999999999993,"name":"point"},"pe":{"x":533,"y":430.75000000000006,"name":"point"},"name":"segment"},{"ps":{"x":533,"y":430.75000000000006,"name":"point"},"pe":{"x":533,"y":431,"name":"point"},"name":"segment"},{"ps":{"x":533,"y":431,"name":"point"},"pe":{"x":531.7,"y":433.6,"name":"point"},"name":"segment"},{"ps":{"x":531.7,"y":433.6,"name":"point"},"pe":{"x":533.1409937888199,"y":438.10310559006217,"name":"point"},"name":"segment"},{"ps":{"x":533.1409937888199,"y":438.10310559006217,"name":"point"},"pe":{"x":533.9477732793523,"y":438.8202429149798,"name":"point"},"name":"segment"},{"ps":{"x":533.9477732793523,"y":438.8202429149798,"name":"point"},"pe":{"x":534.74578313253,"y":439.0915662650602,"name":"point"},"name":"segment"},{"ps":{"x":534.74578313253,"y":439.0915662650602,"name":"point"},"pe":{"x":534.8,"y":439.2,"name":"point"},"name":"segment"},{"ps":{"x":534.8,"y":439.2,"name":"point"},"pe":{"x":534.9610738255034,"y":439.1647651006711,"name":"point"},"name":"segment"},{"ps":{"x":534.9610738255034,"y":439.1647651006711,"name":"point"},"pe":{"x":538.3,"y":440.3,"name":"point"},"name":"segment"},{"ps":{"x":538.3,"y":440.3,"name":"point"},"pe":{"x":539.5378516624038,"y":440.2015345268543,"name":"point"},"name":"segment"},{"ps":{"x":539.5378516624038,"y":440.2015345268543,"name":"point"},"pe":{"x":540.8,"y":439.3,"name":"point"},"name":"segment"},{"ps":{"x":540.8,"y":439.3,"name":"point"},"pe":{"x":545.4874999999998,"y":437.8,"name":"point"},"name":"segment"},{"ps":{"x":545.4874999999998,"y":437.8,"name":"point"},"pe":{"x":545.5,"y":437.8,"name":"point"},"name":"segment"},{"ps":{"x":545.5,"y":437.8,"name":"point"},"pe":{"x":545.8000000000042,"y":437.69999999999834,"name":"point"},"name":"segment"},{"ps":{"x":545.8000000000042,"y":437.69999999999834,"name":"point"},"pe":{"x":553.3,"y":435.3,"name":"point"},"name":"segment"},{"ps":{"x":553.3,"y":435.3,"name":"point"},"pe":{"x":559.8,"y":432.3,"name":"point"},"name":"segment"},{"ps":{"x":559.8,"y":432.3,"name":"point"},"pe":{"x":560.3625,"y":432.6,"name":"point"},"name":"segment"},{"ps":{"x":560.3625,"y":432.6,"name":"point"},"pe":{"x":561.3,"y":432.6,"name":"point"},"name":"segment"},{"ps":{"x":561.3,"y":432.6,"name":"point"},"pe":{"x":563.7,"y":433.6,"name":"point"},"name":"segment"},{"ps":{"x":563.7,"y":433.6,"name":"point"},"pe":{"x":565.5,"y":434.7,"name":"point"},"name":"segment"},{"ps":{"x":565.5,"y":434.7,"name":"point"},"pe":{"x":566.6864516129033,"y":434.43634408602156,"name":"point"},"name":"segment"},{"ps":{"x":566.6864516129033,"y":434.43634408602156,"name":"point"},"pe":{"x":566.8,"y":434.5,"name":"point"},"name":"segment"},{"ps":{"x":566.8,"y":434.5,"name":"point"},"pe":{"x":566.8888888888888,"y":434.3913580246913,"name":"point"},"name":"segment"},{"ps":{"x":566.8888888888888,"y":434.3913580246913,"name":"point"},"pe":{"x":567.7186046511628,"y":434.2069767441861,"name":"point"},"name":"segment"},{"ps":{"x":567.7186046511628,"y":434.2069767441861,"name":"point"},"pe":{"x":567.9382352941177,"y":433.1088235294116,"name":"point"},"name":"segment"},{"ps":{"x":567.9382352941177,"y":433.1088235294116,"name":"point"},"pe":{"x":569.5,"y":431.2,"name":"point"},"name":"segment"},{"ps":{"x":569.5,"y":431.2,"name":"point"},"pe":{"x":570.2,"y":427.8,"name":"point"},"name":"segment"},{"ps":{"x":570.2,"y":427.8,"name":"point"},"pe":{"x":570.5,"y":423.5,"name":"point"},"name":"segment"},{"ps":{"x":570.5,"y":423.5,"name":"point"},"pe":{"x":570.0223880597015,"y":422.68805970149253,"name":"point"},"name":"segment"},{"ps":{"x":570.0223880597015,"y":422.68805970149253,"name":"point"},"pe":{"x":570.3,"y":421.3,"name":"point"},"name":"segment"},{"ps":{"x":570.3,"y":421.3,"name":"point"},"pe":{"x":571.3015384615386,"y":420.96615384615376,"name":"point"},"name":"segment"},{"ps":{"x":571.3015384615386,"y":420.96615384615376,"name":"point"},"pe":{"x":571.7,"y":419.6,"name":"point"},"name":"segment"},{"ps":{"x":571.7,"y":419.6,"name":"point"},"pe":{"x":574.7,"y":419,"name":"point"},"name":"segment"},{"ps":{"x":574.7,"y":419,"name":"point"},"pe":{"x":575.7,"y":420,"name":"point"},"name":"segment"},{"ps":{"x":575.7,"y":420,"name":"point"},"pe":{"x":578,"y":426.3,"name":"point"},"name":"segment"},{"ps":{"x":578,"y":426.3,"name":"point"},"pe":{"x":579.8,"y":426.3,"name":"point"},"name":"segment"},{"ps":{"x":579.8,"y":426.3,"name":"point"},"pe":{"x":586.8,"y":422.8,"name":"point"},"name":"segment"},{"ps":{"x":586.8,"y":422.8,"name":"point"},"pe":{"x":594.3000000000028,"y":420.2999999999991,"name":"point"},"name":"segment"},{"ps":{"x":594.3000000000028,"y":420.2999999999991,"name":"point"},"pe":{"x":595.8,"y":419.8,"name":"point"},"name":"segment"},{"ps":{"x":595.8,"y":419.8,"name":"point"},"pe":{"x":595.3484804630967,"y":421.5308248914614,"name":"point"},"name":"segment"},{"ps":{"x":595.3484804630967,"y":421.5308248914614,"name":"point"},"pe":{"x":596.6,"y":423,"name":"point"},"name":"segment"},{"ps":{"x":596.6,"y":423,"name":"point"},"pe":{"x":596.7947261663286,"y":423.03245436105476,"name":"point"},"name":"segment"},{"ps":{"x":596.7947261663286,"y":423.03245436105476,"name":"point"},"pe":{"x":593.5,"y":429.8,"name":"point"},"name":"segment"},{"ps":{"x":593.5,"y":429.8,"name":"point"},"pe":{"x":595.5,"y":435.5,"name":"point"},"name":"segment"},{"ps":{"x":595.5,"y":435.5,"name":"point"},"pe":{"x":596.1461538461541,"y":437.9923076923084,"name":"point"},"name":"segment"},{"ps":{"x":596.1461538461541,"y":437.9923076923084,"name":"point"},"pe":{"x":596.2464285714285,"y":438.1928571428571,"name":"point"},"name":"segment"},{"ps":{"x":596.2464285714285,"y":438.1928571428571,"name":"point"},"pe":{"x":598.8,"y":437.8,"name":"point"},"name":"segment"},{"ps":{"x":598.8,"y":437.8,"name":"point"},"pe":{"x":599.8811403508773,"y":436.33728070175425,"name":"point"},"name":"segment"},{"ps":{"x":599.8811403508773,"y":436.33728070175425,"name":"point"},"pe":{"x":602.7764127764127,"y":429.43316953316935,"name":"point"},"name":"segment"},{"ps":{"x":602.7764127764127,"y":429.43316953316935,"name":"point"},"pe":{"x":602.2,"y":427.8,"name":"point"},"name":"segment"},{"ps":{"x":602.2,"y":427.8,"name":"point"},"pe":{"x":602.2,"y":425.5,"name":"point"},"name":"segment"},{"ps":{"x":602.2,"y":425.5,"name":"point"},"pe":{"x":602.7065743944636,"y":424.0647058823528,"name":"point"},"name":"segment"},{"ps":{"x":602.7065743944636,"y":424.0647058823528,"name":"point"},"pe":{"x":605.4,"y":425.7,"name":"point"},"name":"segment"},{"ps":{"x":605.4,"y":425.7,"name":"point"},"pe":{"x":604.8,"y":425.8,"name":"point"},"name":"segment"},{"ps":{"x":604.8,"y":425.8,"name":"point"},"pe":{"x":605.3161290322583,"y":426.02580645161305,"name":"point"},"name":"segment"},{"ps":{"x":605.3161290322583,"y":426.02580645161305,"name":"point"},"pe":{"x":605.8206896551726,"y":426.13793103448296,"name":"point"},"name":"segment"},{"ps":{"x":605.8206896551726,"y":426.13793103448296,"name":"point"},"pe":{"x":605.6,"y":426,"name":"point"},"name":"segment"},{"ps":{"x":605.6,"y":426,"name":"point"},"pe":{"x":607.4349083895853,"y":425.97261330761813,"name":"point"},"name":"segment"},{"ps":{"x":607.4349083895853,"y":425.97261330761813,"name":"point"},"pe":{"x":609.2,"y":426.8,"name":"point"},"name":"segment"},{"ps":{"x":609.2,"y":426.8,"name":"point"},"pe":{"x":609.8233025984912,"y":425.93696563285835,"name":"point"},"name":"segment"},{"ps":{"x":609.8233025984912,"y":425.93696563285835,"name":"point"},"pe":{"x":612.3,"y":425.9,"name":"point"},"name":"segment"},{"ps":{"x":612.3,"y":425.9,"name":"point"},"pe":{"x":613.3,"y":424,"name":"point"},"name":"segment"},{"ps":{"x":613.3,"y":424,"name":"point"},"pe":{"x":614.610344827586,"y":423.541379310345,"name":"point"},"name":"segment"},{"ps":{"x":614.610344827586,"y":423.541379310345,"name":"point"},"pe":{"x":614.8,"y":423.3,"name":"point"},"name":"segment"},{"ps":{"x":614.8,"y":423.3,"name":"point"},"pe":{"x":615.2200000000003,"y":423.32800000000003,"name":"point"},"name":"segment"},{"ps":{"x":615.2200000000003,"y":423.32800000000003,"name":"point"},"pe":{"x":615.3,"y":423.3,"name":"point"},"name":"segment"},{"ps":{"x":615.3,"y":423.3,"name":"point"},"pe":{"x":615.7051724137923,"y":423.3603448275862,"name":"point"},"name":"segment"},{"ps":{"x":615.7051724137923,"y":423.3603448275862,"name":"point"},"pe":{"x":620.4450381679391,"y":423.6763358778625,"name":"point"},"name":"segment"},{"ps":{"x":620.4450381679391,"y":423.6763358778625,"name":"point"},"pe":{"x":623.3,"y":421.6000000000001,"name":"point"},"name":"segment"},{"ps":{"x":623.3,"y":421.6000000000001,"name":"point"},"pe":{"x":625.3999999999997,"y":416.98,"name":"point"},"name":"segment"},{"ps":{"x":625.3999999999997,"y":416.98,"name":"point"},"pe":{"x":625.8,"y":416.5,"name":"point"},"name":"segment"},{"ps":{"x":625.8,"y":416.5,"name":"point"},"pe":{"x":627.5209302325579,"y":412.3139534883709,"name":"point"},"name":"segment"},{"ps":{"x":627.5209302325579,"y":412.3139534883709,"name":"point"},"pe":{"x":629.1474264705897,"y":408.73566176470115,"name":"point"},"name":"segment"},{"ps":{"x":629.1474264705897,"y":408.73566176470115,"name":"point"},"pe":{"x":629.4144013880857,"y":407.708212839792,"name":"point"},"name":"segment"},{"ps":{"x":629.4144013880857,"y":407.708212839792,"name":"point"},"pe":{"x":629.5,"y":407.5,"name":"point"},"name":"segment"},{"ps":{"x":629.5,"y":407.5,"name":"point"},"pe":{"x":629.4893858984078,"y":407.4196360879452,"name":"point"},"name":"segment"},{"ps":{"x":629.4893858984078,"y":407.4196360879452,"name":"point"},"pe":{"x":630.3,"y":404.3,"name":"point"},"name":"segment"},{"ps":{"x":630.3,"y":404.3,"name":"point"},"pe":{"x":633.3,"y":397,"name":"point"},"name":"segment"},{"ps":{"x":633.3,"y":397,"name":"point"},"pe":{"x":634.6,"y":396.74,"name":"point"},"name":"segment"},{"ps":{"x":634.6,"y":396.74,"name":"point"},"pe":{"x":634.8,"y":396.3,"name":"point"},"name":"segment"},{"ps":{"x":634.8,"y":396.3,"name":"point"},"pe":{"x":635.2472049689441,"y":396.61055900621113,"name":"point"},"name":"segment"},{"ps":{"x":635.2472049689441,"y":396.61055900621113,"name":"point"},"pe":{"x":635.3,"y":396.6,"name":"point"},"name":"segment"},{"ps":{"x":635.3,"y":396.6,"name":"point"},"pe":{"x":635.3136504014824,"y":396.65670166769615,"name":"point"},"name":"segment"},{"ps":{"x":635.3136504014824,"y":396.65670166769615,"name":"point"},"pe":{"x":635.8961248112734,"y":397.0611977856065,"name":"point"},"name":"segment"},{"ps":{"x":635.8961248112734,"y":397.0611977856065,"name":"point"},"pe":{"x":637.2,"y":402.2,"name":"point"},"name":"segment"},{"ps":{"x":637.2,"y":402.2,"name":"point"},"pe":{"x":637.8,"y":409.8,"name":"point"},"name":"segment"},{"ps":{"x":637.8,"y":409.8,"name":"point"},"pe":{"x":650.3633187772926,"y":407.1078602620087,"name":"point"},"name":"segment"},{"ps":{"x":650.3633187772926,"y":407.1078602620087,"name":"point"},"pe":{"x":652.8,"y":408.8,"name":"point"},"name":"segment"},{"ps":{"x":652.8,"y":408.8,"name":"point"},"pe":{"x":654.1391684901531,"y":411.7759299781182,"name":"point"},"name":"segment"},{"ps":{"x":654.1391684901531,"y":411.7759299781182,"name":"point"},"pe":{"x":653.8589003054708,"y":411.99025270758113,"name":"point"},"name":"segment"},{"ps":{"x":653.8589003054708,"y":411.99025270758113,"name":"point"},"pe":{"x":659.9,"y":424.9,"name":"point"},"name":"segment"},{"ps":{"x":659.9,"y":424.9,"name":"point"},"pe":{"x":660.1636363636363,"y":425.16363636363616,"name":"point"},"name":"segment"},{"ps":{"x":660.1636363636363,"y":425.16363636363616,"name":"point"},"pe":{"x":660.4747252747255,"y":425.8549450549451,"name":"point"},"name":"segment"},{"ps":{"x":660.4747252747255,"y":425.8549450549451,"name":"point"},"pe":{"x":660.95,"y":425.95,"name":"point"},"name":"segment"},{"ps":{"x":660.95,"y":425.95,"name":"point"},"pe":{"x":662.6285714285714,"y":427.62857142857126,"name":"point"},"name":"segment"},{"ps":{"x":662.6285714285714,"y":427.62857142857126,"name":"point"},"pe":{"x":662.8,"y":428.2,"name":"point"},"name":"segment"},{"ps":{"x":662.8,"y":428.2,"name":"point"},"pe":{"x":662.8,"y":428.5222222222222,"name":"point"},"name":"segment"},{"ps":{"x":662.8,"y":428.5222222222222,"name":"point"},"pe":{"x":663.3652173913043,"y":428.36521739130427,"name":"point"},"name":"segment"},{"ps":{"x":663.3652173913043,"y":428.36521739130427,"name":"point"},"pe":{"x":664.3,"y":429.3,"name":"point"},"name":"segment"},{"ps":{"x":664.3,"y":429.3,"name":"point"},"pe":{"x":666.7,"y":429.9,"name":"point"},"name":"segment"},{"ps":{"x":666.7,"y":429.9,"name":"point"},"pe":{"x":676.9880421243348,"y":424.80405390103044,"name":"point"},"name":"segment"},{"ps":{"x":676.9880421243348,"y":424.80405390103044,"name":"point"},"pe":{"x":677.0046511627908,"y":424.6,"name":"point"},"name":"segment"},{"ps":{"x":677.0046511627908,"y":424.6,"name":"point"},"pe":{"x":676.9199999999996,"y":424.6,"name":"point"},"name":"segment"},{"ps":{"x":676.9199999999996,"y":424.6,"name":"point"},"pe":{"x":677.0066093853271,"y":424.57594183740895,"name":"point"},"name":"segment"},{"ps":{"x":677.0066093853271,"y":424.57594183740895,"name":"point"},"pe":{"x":677.0326693227092,"y":424.2557768924303,"name":"point"},"name":"segment"},{"ps":{"x":677.0326693227092,"y":424.2557768924303,"name":"point"},"pe":{"x":679,"y":423.6,"name":"point"},"name":"segment"},{"ps":{"x":679,"y":423.6,"name":"point"},"pe":{"x":682.357482185273,"y":421.67707838479805,"name":"point"},"name":"segment"},{"ps":{"x":682.357482185273,"y":421.67707838479805,"name":"point"},"pe":{"x":682.8,"y":421.8,"name":"point"},"name":"segment"},{"ps":{"x":682.8,"y":421.8,"name":"point"},"pe":{"x":682.8180505415162,"y":421.8794223826715,"name":"point"},"name":"segment"},{"ps":{"x":682.8180505415162,"y":421.8794223826715,"name":"point"},"pe":{"x":687.5974683544301,"y":418.8379746835445,"name":"point"},"name":"segment"},{"ps":{"x":687.5974683544301,"y":418.8379746835445,"name":"point"},"pe":{"x":687.6086956521738,"y":418.66956521739127,"name":"point"},"name":"segment"},{"ps":{"x":687.6086956521738,"y":418.66956521739127,"name":"point"},"pe":{"x":690,"y":417.3,"name":"point"},"name":"segment"},{"ps":{"x":690,"y":417.3,"name":"point"},"pe":{"x":690.0055555555555,"y":417.30555555555554,"name":"point"},"name":"segment"},{"ps":{"x":690.0055555555555,"y":417.30555555555554,"name":"point"},"pe":{"x":690.8,"y":416.8,"name":"point"},"name":"segment"},{"ps":{"x":690.8,"y":416.8,"name":"point"},"pe":{"x":692.8728943338436,"y":417.77886676875954,"name":"point"},"name":"segment"},{"ps":{"x":692.8728943338436,"y":417.77886676875954,"name":"point"},"pe":{"x":693.5,"y":426.2,"name":"point"},"name":"segment"},{"ps":{"x":693.5,"y":426.2,"name":"point"},"pe":{"x":694.8,"y":428.5,"name":"point"},"name":"segment"},{"ps":{"x":694.8,"y":428.5,"name":"point"},"pe":{"x":695.5,"y":432.8,"name":"point"},"name":"segment"},{"ps":{"x":695.5,"y":432.8,"name":"point"},"pe":{"x":698.2,"y":432.8,"name":"point"},"name":"segment"},{"ps":{"x":698.2,"y":432.8,"name":"point"},"pe":{"x":704.9888039661226,"y":423.50026853955796,"name":"point"},"name":"segment"},{"ps":{"x":704.9888039661226,"y":423.50026853955796,"name":"point"},"pe":{"x":707.4083618917066,"y":424.64283755997263,"name":"point"},"name":"segment"},{"ps":{"x":707.4083618917066,"y":424.64283755997263,"name":"point"},"pe":{"x":708,"y":424,"name":"point"},"name":"segment"},{"ps":{"x":708,"y":424,"name":"point"},"pe":{"x":708,"y":424.9222222222223,"name":"point"},"name":"segment"},{"ps":{"x":708,"y":424.9222222222223,"name":"point"},"pe":{"x":708.8,"y":425.3,"name":"point"},"name":"segment"},{"ps":{"x":708.8,"y":425.3,"name":"point"},"pe":{"x":708.1976878612716,"y":429.2150289017341,"name":"point"},"name":"segment"},{"ps":{"x":708.1976878612716,"y":429.2150289017341,"name":"point"},"pe":{"x":707.5,"y":430.2,"name":"point"},"name":"segment"},{"ps":{"x":707.5,"y":430.2,"name":"point"},"pe":{"x":704.5,"y":433.2,"name":"point"},"name":"segment"},{"ps":{"x":704.5,"y":433.2,"name":"point"},"pe":{"x":703.2560975609756,"y":436.060975609756,"name":"point"},"name":"segment"},{"ps":{"x":703.2560975609756,"y":436.060975609756,"name":"point"},"pe":{"x":704.2222222222222,"y":437.8,"name":"point"},"name":"segment"},{"ps":{"x":704.2222222222222,"y":437.8,"name":"point"},"pe":{"x":706.8769230769229,"y":437.8,"name":"point"},"name":"segment"},{"ps":{"x":706.8769230769229,"y":437.8,"name":"point"},"pe":{"x":706.8,"y":438.3,"name":"point"},"name":"segment"},{"ps":{"x":706.8,"y":438.3,"name":"point"},"pe":{"x":709.1390862944162,"y":440.44416243654825,"name":"point"},"name":"segment"},{"ps":{"x":709.1390862944162,"y":440.44416243654825,"name":"point"},"pe":{"x":711.3,"y":441.6,"name":"point"},"name":"segment"},{"ps":{"x":711.3,"y":441.6,"name":"point"},"pe":{"x":714.2224376731302,"y":444.3470914127425,"name":"point"},"name":"segment"},{"ps":{"x":714.2224376731302,"y":444.3470914127425,"name":"point"},"pe":{"x":718.1776978417267,"y":445.86834532374104,"name":"point"},"name":"segment"},{"ps":{"x":718.1776978417267,"y":445.86834532374104,"name":"point"},"pe":{"x":721.853191489362,"y":445.02340425531924,"name":"point"},"name":"segment"},{"ps":{"x":721.853191489362,"y":445.02340425531924,"name":"point"},"pe":{"x":723.3,"y":444.3,"name":"point"},"name":"segment"},{"ps":{"x":723.3,"y":444.3,"name":"point"},"pe":{"x":724.4012145748989,"y":444.4376518218625,"name":"point"},"name":"segment"},{"ps":{"x":724.4012145748989,"y":444.4376518218625,"name":"point"},"pe":{"x":725,"y":444.3,"name":"point"},"name":"segment"},{"ps":{"x":725,"y":444.3,"name":"point"},"pe":{"x":730.3,"y":443.6,"name":"point"},"name":"segment"},{"ps":{"x":730.3,"y":443.6,"name":"point"},"pe":{"x":733.9156521739131,"y":445.62695652173926,"name":"point"},"name":"segment"},{"ps":{"x":733.9156521739131,"y":445.62695652173926,"name":"point"},"pe":{"x":735.3,"y":445.8,"name":"point"},"name":"segment"},{"ps":{"x":735.3,"y":445.8,"name":"point"},"pe":{"x":741.8,"y":445.8,"name":"point"},"name":"segment"},{"ps":{"x":741.8,"y":445.8,"name":"point"},"pe":{"x":742.1687969924812,"y":445.14436090225564,"name":"point"},"name":"segment"},{"ps":{"x":742.1687969924812,"y":445.14436090225564,"name":"point"},"pe":{"x":743.2345314505778,"y":445.62695763799746,"name":"point"},"name":"segment"},{"ps":{"x":743.2345314505778,"y":445.62695763799746,"name":"point"},"pe":{"x":743.3,"y":445.6,"name":"point"},"name":"segment"},{"ps":{"x":743.3,"y":445.6,"name":"point"},"pe":{"x":744.419018404908,"y":445.3901840490798,"name":"point"},"name":"segment"},{"ps":{"x":744.419018404908,"y":445.3901840490798,"name":"point"},"pe":{"x":744.2,"y":443.2,"name":"point"},"name":"segment"},{"ps":{"x":744.2,"y":443.2,"name":"point"},"pe":{"x":743.9540983606557,"y":441.9704918032786,"name":"point"},"name":"segment"},{"ps":{"x":743.9540983606557,"y":441.9704918032786,"name":"point"},"pe":{"x":744.6422857142858,"y":440.7470476190477,"name":"point"},"name":"segment"},{"ps":{"x":744.6422857142858,"y":440.7470476190477,"name":"point"},"pe":{"x":744.6,"y":440,"name":"point"},"name":"segment"},{"ps":{"x":744.6,"y":440,"name":"point"},"pe":{"x":745.6,"y":438.3,"name":"point"},"name":"segment"},{"ps":{"x":745.6,"y":438.3,"name":"point"},"pe":{"x":746.0498233215546,"y":438.24475853945813,"name":"point"},"name":"segment"},{"ps":{"x":746.0498233215546,"y":438.24475853945813,"name":"point"},"pe":{"x":746.3,"y":437.8,"name":"point"},"name":"segment"},{"ps":{"x":746.3,"y":437.8,"name":"point"},"pe":{"x":747.0298969072162,"y":438.1243986254295,"name":"point"},"name":"segment"},{"ps":{"x":747.0298969072162,"y":438.1243986254295,"name":"point"},"pe":{"x":751.3,"y":437.6,"name":"point"},"name":"segment"},{"ps":{"x":751.3,"y":437.6,"name":"point"},"pe":{"x":751.3,"y":439.96666666666664,"name":"point"},"name":"segment"},{"ps":{"x":751.3,"y":439.96666666666664,"name":"point"},"pe":{"x":753.1612903225806,"y":440.5870967741936,"name":"point"},"name":"segment"},{"ps":{"x":753.1612903225806,"y":440.5870967741936,"name":"point"},"pe":{"x":752.8,"y":444.2,"name":"point"},"name":"segment"},{"ps":{"x":752.8,"y":444.2,"name":"point"},"pe":{"x":757.2,"y":446.2,"name":"point"},"name":"segment"},{"ps":{"x":757.2,"y":446.2,"name":"point"},"pe":{"x":758.9810559006212,"y":447.5654761904762,"name":"point"},"name":"segment"},{"ps":{"x":758.9810559006212,"y":447.5654761904762,"name":"point"},"pe":{"x":761.3838747099769,"y":446.5420533642691,"name":"point"},"name":"segment"},{"ps":{"x":761.3838747099769,"y":446.5420533642691,"name":"point"},"pe":{"x":762.8,"y":444.2,"name":"point"},"name":"segment"},{"ps":{"x":762.8,"y":444.2,"name":"point"},"pe":{"x":763.3454545454546,"y":443.9818181818182,"name":"point"},"name":"segment"},{"ps":{"x":763.3454545454546,"y":443.9818181818182,"name":"point"},"pe":{"x":764.3,"y":444.3,"name":"point"},"name":"segment"},{"ps":{"x":764.3,"y":444.3,"name":"point"},"pe":{"x":764.3,"y":445.3,"name":"point"},"name":"segment"},{"ps":{"x":764.3,"y":445.3,"name":"point"},"pe":{"x":765.6,"y":445.3,"name":"point"},"name":"segment"},{"ps":{"x":765.6,"y":445.3,"name":"point"},"pe":{"x":764.9,"y":449,"name":"point"},"name":"segment"},{"ps":{"x":764.9,"y":449,"name":"point"},"pe":{"x":764.6,"y":453.3,"name":"point"},"name":"segment"},{"ps":{"x":764.6,"y":453.3,"name":"point"},"pe":{"x":766.9,"y":454,"name":"point"},"name":"segment"},{"ps":{"x":766.9,"y":454,"name":"point"},"pe":{"x":780.2496868475996,"y":455.45302713987485,"name":"point"},"name":"segment"},{"ps":{"x":780.2496868475996,"y":455.45302713987485,"name":"point"},"pe":{"x":786.8,"y":457.5,"name":"point"},"name":"segment"},{"ps":{"x":786.8,"y":457.5,"name":"point"},"pe":{"x":785.5,"y":458.5,"name":"point"},"name":"segment"},{"ps":{"x":785.5,"y":458.5,"name":"point"},"pe":{"x":782.5,"y":458.5,"name":"point"},"name":"segment"},{"ps":{"x":782.5,"y":458.5,"name":"point"},"pe":{"x":757.1344066237349,"y":460.2519779208832,"name":"point"},"name":"segment"},{"ps":{"x":757.1344066237349,"y":460.2519779208832,"name":"point"},"pe":{"x":748.3,"y":460.6,"name":"point"},"name":"segment"},{"ps":{"x":748.3,"y":460.6,"name":"point"},"pe":{"x":725.3,"y":460.3,"name":"point"},"name":"segment"},{"ps":{"x":725.3,"y":460.3,"name":"point"},"pe":{"x":645.6,"y":462,"name":"point"},"name":"segment"},{"ps":{"x":645.6,"y":462,"name":"point"},"pe":{"x":622.4,"y":462.3,"name":"point"},"name":"segment"},{"ps":{"x":622.4,"y":462.3,"name":"point"},"pe":{"x":605,"y":464.3,"name":"point"},"name":"segment"},{"ps":{"x":605,"y":464.3,"name":"point"},"pe":{"x":567.7751724137913,"y":465.0158620689656,"name":"point"},"name":"segment"},{"ps":{"x":567.7751724137913,"y":465.0158620689656,"name":"point"},"pe":{"x":563.3,"y":465.3,"name":"point"},"name":"segment"},{"ps":{"x":563.3,"y":465.3,"name":"point"},"pe":{"x":524.3033434650456,"y":469.88784194528876,"name":"point"},"name":"segment"},{"ps":{"x":524.3033434650456,"y":469.88784194528876,"name":"point"},"pe":{"x":524.2,"y":469.8,"name":"point"},"name":"segment"},{"ps":{"x":524.2,"y":469.8,"name":"point"},"pe":{"x":520.0857142857142,"y":469.8,"name":"point"},"name":"segment"},{"ps":{"x":520.0857142857142,"y":469.8,"name":"point"},"pe":{"x":515.8,"y":466.8,"name":"point"},"name":"segment"},{"ps":{"x":515.8,"y":466.8,"name":"point"},"pe":{"x":514.7151219512195,"y":466.4609756097562,"name":"point"},"name":"segment"},{"ps":{"x":514.7151219512195,"y":466.4609756097562,"name":"point"},"pe":{"x":514.5186785260483,"y":466.04002541296063,"name":"point"},"name":"segment"},{"ps":{"x":514.5186785260483,"y":466.04002541296063,"name":"point"},"pe":{"x":513.4347826086957,"y":466.0608695652174,"name":"point"},"name":"segment"},{"ps":{"x":513.4347826086957,"y":466.0608695652174,"name":"point"},"pe":{"x":509.7435528500277,"y":464.90736026563366,"name":"point"},"name":"segment"},{"ps":{"x":509.7435528500277,"y":464.90736026563366,"name":"point"},"pe":{"x":508.5535239810852,"y":466.1547399234408,"name":"point"},"name":"segment"},{"ps":{"x":508.5535239810852,"y":466.1547399234408,"name":"point"},"pe":{"x":506.1709497206705,"y":466.2005586592179,"name":"point"},"name":"segment"},{"ps":{"x":506.1709497206705,"y":466.2005586592179,"name":"point"},"pe":{"x":501.8,"y":471.3,"name":"point"},"name":"segment"},{"ps":{"x":501.8,"y":471.3,"name":"point"},"pe":{"x":496.3,"y":470.3,"name":"point"},"name":"segment"},{"ps":{"x":496.3,"y":470.3,"name":"point"},"pe":{"x":491.8,"y":476.8,"name":"point"},"name":"segment"},{"ps":{"x":491.8,"y":476.8,"name":"point"},"pe":{"x":487.24683544303804,"y":480.52531645569616,"name":"point"},"name":"segment"},{"ps":{"x":487.24683544303804,"y":480.52531645569616,"name":"point"},"pe":{"x":485.39595375722547,"y":480.7104046242774,"name":"point"},"name":"segment"},{"ps":{"x":485.39595375722547,"y":480.7104046242774,"name":"point"},"pe":{"x":474.8,"y":473.8,"name":"point"},"name":"segment"},{"ps":{"x":474.8,"y":473.8,"name":"point"},"pe":{"x":493.8,"y":460.3,"name":"point"},"name":"segment"},{"ps":{"x":493.8,"y":460.3,"name":"point"},"pe":{"x":489.8,"y":454.8,"name":"point"},"name":"segment"},{"ps":{"x":489.8,"y":454.8,"name":"point"},"pe":{"x":490.286346300534,"y":453.2193745232649,"name":"point"},"name":"segment"},{"ps":{"x":490.286346300534,"y":453.2193745232649,"name":"point"},"pe":{"x":489.3,"y":451.6,"name":"point"},"name":"segment"},{"ps":{"x":489.3,"y":451.6,"name":"point"},"pe":{"x":491.0807980049874,"y":450.63740648379087,"name":"point"},"name":"segment"},{"ps":{"x":491.0807980049874,"y":450.63740648379087,"name":"point"},"pe":{"x":491.7792207792208,"y":448.36753246753244,"name":"point"},"name":"segment"},{"ps":{"x":491.7792207792208,"y":448.36753246753244,"name":"point"},"pe":{"x":492.5,"y":448.8,"name":"point"},"name":"segment"},{"ps":{"x":492.5,"y":448.8,"name":"point"},"pe":{"x":495.6999999999999,"y":449.6,"name":"point"},"name":"segment"}]]`;
            //const json1 = `[[{"ps":{"x":495.6999999999999,"y":449.6,"name":"point"},"pe":{"x":500.62352941176465,"y":449.6,"name":"point"},"name":"segment"},{"ps":{"x":500.62352941176465,"y":449.6,"name":"point"},"pe":{"x":500.8,"y":449.5,"name":"point"},"name":"segment"},{"ps":{"x":500.8,"y":449.5,"name":"point"},"pe":{"x":501.6222222222222,"y":448.67777777777775,"name":"point"},"name":"segment"},{"ps":{"x":501.6222222222222,"y":448.67777777777775,"name":"point"},"pe":{"x":504.8,"y":448.8,"name":"point"},"name":"segment"},{"ps":{"x":504.8,"y":448.8,"name":"point"},"pe":{"x":507.11999999999995,"y":448.21999999999997,"name":"point"},"name":"segment"},{"ps":{"x":507.11999999999995,"y":448.21999999999997,"name":"point"},"pe":{"x":507.5,"y":448.2,"name":"point"},"name":"segment"},{"ps":{"x":507.5,"y":448.2,"name":"point"},"pe":{"x":510.16305569749636,"y":447.76647930505874,"name":"point"},"name":"segment"},{"ps":{"x":510.16305569749636,"y":447.76647930505874,"name":"point"},"pe":{"x":512.0000000000002,"y":445.64999999999986,"name":"point"},"name":"segment"},{"ps":{"x":512.0000000000002,"y":445.64999999999986,"name":"point"},"pe":{"x":512.2,"y":443.8,"name":"point"},"name":"segment"},{"ps":{"x":512.2,"y":443.8,"name":"point"},"pe":{"x":512.4352941176471,"y":442.9529411764702,"name":"point"},"name":"segment"},{"ps":{"x":512.4352941176471,"y":442.9529411764702,"name":"point"},"pe":{"x":513.3,"y":441.8,"name":"point"},"name":"segment"},{"ps":{"x":513.3,"y":441.8,"name":"point"},"pe":{"x":515.0562499999997,"y":438.2875000000002,"name":"point"},"name":"segment"},{"ps":{"x":515.0562499999997,"y":438.2875000000002,"name":"point"},"pe":{"x":516.5,"y":436.8,"name":"point"},"name":"segment"},{"ps":{"x":516.5,"y":436.8,"name":"point"},"pe":{"x":516.5893617021277,"y":435.22127659574465,"name":"point"},"name":"segment"},{"ps":{"x":516.5893617021277,"y":435.22127659574465,"name":"point"},"pe":{"x":519.8,"y":428.8,"name":"point"},"name":"segment"},{"ps":{"x":519.8,"y":428.8,"name":"point"},"pe":{"x":521.3303326810178,"y":426.90958904109596,"name":"point"},"name":"segment"},{"ps":{"x":521.3303326810178,"y":426.90958904109596,"name":"point"},"pe":{"x":521.8,"y":426.8,"name":"point"},"name":"segment"},{"ps":{"x":521.8,"y":426.8,"name":"point"},"pe":{"x":523.5,"y":426.8,"name":"point"},"name":"segment"},{"ps":{"x":523.5,"y":426.8,"name":"point"},"pe":{"x":524.4297872340426,"y":423.08085106382975,"name":"point"},"name":"segment"},{"ps":{"x":524.4297872340426,"y":423.08085106382975,"name":"point"},"pe":{"x":526.8443113772455,"y":420.0982035928144,"name":"point"},"name":"segment"},{"ps":{"x":526.8443113772455,"y":420.0982035928144,"name":"point"},"pe":{"x":527,"y":419.6,"name":"point"},"name":"segment"},{"ps":{"x":527,"y":419.6,"name":"point"},"pe":{"x":527.254258675079,"y":419.5917981072555,"name":"point"},"name":"segment"},{"ps":{"x":527.254258675079,"y":419.5917981072555,"name":"point"},"pe":{"x":528.3,"y":418.3,"name":"point"},"name":"segment"},{"ps":{"x":528.3,"y":418.3,"name":"point"},"pe":{"x":536.9370833333332,"y":418.7545833333333,"name":"point"},"name":"segment"},{"ps":{"x":536.9370833333332,"y":418.7545833333333,"name":"point"},"pe":{"x":537.4696969696968,"y":419.7437229437229,"name":"point"},"name":"segment"},{"ps":{"x":537.4696969696968,"y":419.7437229437229,"name":"point"},"pe":{"x":536.273933649289,"y":423.1601895734599,"name":"point"},"name":"segment"},{"ps":{"x":536.273933649289,"y":423.1601895734599,"name":"point"},"pe":{"x":536.2,"y":423.2,"name":"point"},"name":"segment"},{"ps":{"x":536.2,"y":423.2,"name":"point"},"pe":{"x":534.5,"y":425.5,"name":"point"},"name":"segment"},{"ps":{"x":534.5,"y":425.5,"name":"point"},"pe":{"x":534.2,"y":428.2,"name":"point"},"name":"segment"},{"ps":{"x":534.2,"y":428.2,"name":"point"},"pe":{"x":534.2,"y":428.94999999999993,"name":"point"},"name":"segment"},{"ps":{"x":534.2,"y":428.94999999999993,"name":"point"},"pe":{"x":533,"y":430.75000000000006,"name":"point"},"name":"segment"},{"ps":{"x":533,"y":430.75000000000006,"name":"point"},"pe":{"x":533,"y":431,"name":"point"},"name":"segment"},{"ps":{"x":533,"y":431,"name":"point"},"pe":{"x":531.7,"y":433.6,"name":"point"},"name":"segment"},{"ps":{"x":531.7,"y":433.6,"name":"point"},"pe":{"x":533.1409937888199,"y":438.10310559006217,"name":"point"},"name":"segment"},{"ps":{"x":533.1409937888199,"y":438.10310559006217,"name":"point"},"pe":{"x":533.9477732793523,"y":438.8202429149798,"name":"point"},"name":"segment"},{"ps":{"x":533.9477732793523,"y":438.8202429149798,"name":"point"},"pe":{"x":534.74578313253,"y":439.0915662650602,"name":"point"},"name":"segment"},{"ps":{"x":534.74578313253,"y":439.0915662650602,"name":"point"},"pe":{"x":534.8,"y":439.2,"name":"point"},"name":"segment"},{"ps":{"x":534.8,"y":439.2,"name":"point"},"pe":{"x":534.9610738255034,"y":439.1647651006711,"name":"point"},"name":"segment"},{"ps":{"x":534.9610738255034,"y":439.1647651006711,"name":"point"},"pe":{"x":538.3,"y":440.3,"name":"point"},"name":"segment"},{"ps":{"x":538.3,"y":440.3,"name":"point"},"pe":{"x":539.5378516624038,"y":440.2015345268543,"name":"point"},"name":"segment"},{"ps":{"x":539.5378516624038,"y":440.2015345268543,"name":"point"},"pe":{"x":540.8,"y":439.3,"name":"point"},"name":"segment"},{"ps":{"x":540.8,"y":439.3,"name":"point"},"pe":{"x":545.4874999999998,"y":437.8,"name":"point"},"name":"segment"},{"ps":{"x":545.4874999999998,"y":437.8,"name":"point"},"pe":{"x":545.5,"y":437.8,"name":"point"},"name":"segment"},{"ps":{"x":545.5,"y":437.8,"name":"point"},"pe":{"x":545.8000000000042,"y":437.69999999999834,"name":"point"},"name":"segment"},{"ps":{"x":545.8000000000042,"y":437.69999999999834,"name":"point"},"pe":{"x":553.3,"y":435.3,"name":"point"},"name":"segment"},{"ps":{"x":553.3,"y":435.3,"name":"point"},"pe":{"x":559.8,"y":432.3,"name":"point"},"name":"segment"},{"ps":{"x":559.8,"y":432.3,"name":"point"},"pe":{"x":560.3625,"y":432.6,"name":"point"},"name":"segment"},{"ps":{"x":560.3625,"y":432.6,"name":"point"},"pe":{"x":561.3,"y":432.6,"name":"point"},"name":"segment"},{"ps":{"x":561.3,"y":432.6,"name":"point"},"pe":{"x":563.7,"y":433.6,"name":"point"},"name":"segment"},{"ps":{"x":563.7,"y":433.6,"name":"point"},"pe":{"x":565.5,"y":434.7,"name":"point"},"name":"segment"},{"ps":{"x":565.5,"y":434.7,"name":"point"},"pe":{"x":566.6864516129033,"y":434.43634408602156,"name":"point"},"name":"segment"},{"ps":{"x":566.6864516129033,"y":434.43634408602156,"name":"point"},"pe":{"x":566.8,"y":434.5,"name":"point"},"name":"segment"},{"ps":{"x":566.8,"y":434.5,"name":"point"},"pe":{"x":566.8888888888888,"y":434.3913580246913,"name":"point"},"name":"segment"},{"ps":{"x":566.8888888888888,"y":434.3913580246913,"name":"point"},"pe":{"x":567.7186046511628,"y":434.2069767441861,"name":"point"},"name":"segment"},{"ps":{"x":567.7186046511628,"y":434.2069767441861,"name":"point"},"pe":{"x":567.9382352941177,"y":433.1088235294116,"name":"point"},"name":"segment"},{"ps":{"x":567.9382352941177,"y":433.1088235294116,"name":"point"},"pe":{"x":569.5,"y":431.2,"name":"point"},"name":"segment"},{"ps":{"x":569.5,"y":431.2,"name":"point"},"pe":{"x":570.2,"y":427.8,"name":"point"},"name":"segment"},{"ps":{"x":570.2,"y":427.8,"name":"point"},"pe":{"x":570.5,"y":423.5,"name":"point"},"name":"segment"},{"ps":{"x":570.5,"y":423.5,"name":"point"},"pe":{"x":570.0223880597015,"y":422.68805970149253,"name":"point"},"name":"segment"},{"ps":{"x":570.0223880597015,"y":422.68805970149253,"name":"point"},"pe":{"x":570.3,"y":421.3,"name":"point"},"name":"segment"},{"ps":{"x":570.3,"y":421.3,"name":"point"},"pe":{"x":571.3015384615386,"y":420.96615384615376,"name":"point"},"name":"segment"},{"ps":{"x":571.3015384615386,"y":420.96615384615376,"name":"point"},"pe":{"x":571.7,"y":419.6,"name":"point"},"name":"segment"},{"ps":{"x":571.7,"y":419.6,"name":"point"},"pe":{"x":574.7,"y":419,"name":"point"},"name":"segment"},{"ps":{"x":574.7,"y":419,"name":"point"},"pe":{"x":575.7,"y":420,"name":"point"},"name":"segment"},{"ps":{"x":575.7,"y":420,"name":"point"},"pe":{"x":578,"y":426.3,"name":"point"},"name":"segment"},{"ps":{"x":578,"y":426.3,"name":"point"},"pe":{"x":579.8,"y":426.3,"name":"point"},"name":"segment"},{"ps":{"x":579.8,"y":426.3,"name":"point"},"pe":{"x":586.8,"y":422.8,"name":"point"},"name":"segment"},{"ps":{"x":586.8,"y":422.8,"name":"point"},"pe":{"x":594.3000000000028,"y":420.2999999999991,"name":"point"},"name":"segment"},{"ps":{"x":594.3000000000028,"y":420.2999999999991,"name":"point"},"pe":{"x":595.8,"y":419.8,"name":"point"},"name":"segment"},{"ps":{"x":595.8,"y":419.8,"name":"point"},"pe":{"x":595.3484804630967,"y":421.5308248914614,"name":"point"},"name":"segment"},{"ps":{"x":595.3484804630967,"y":421.5308248914614,"name":"point"},"pe":{"x":596.6,"y":423,"name":"point"},"name":"segment"},{"ps":{"x":596.6,"y":423,"name":"point"},"pe":{"x":596.7947261663286,"y":423.03245436105476,"name":"point"},"name":"segment"},{"ps":{"x":596.7947261663286,"y":423.03245436105476,"name":"point"},"pe":{"x":593.5,"y":429.8,"name":"point"},"name":"segment"},{"ps":{"x":593.5,"y":429.8,"name":"point"},"pe":{"x":595.5,"y":435.5,"name":"point"},"name":"segment"},{"ps":{"x":595.5,"y":435.5,"name":"point"},"pe":{"x":596.1461538461541,"y":437.9923076923084,"name":"point"},"name":"segment"},{"ps":{"x":596.1461538461541,"y":437.9923076923084,"name":"point"},"pe":{"x":596.2464285714285,"y":438.1928571428571,"name":"point"},"name":"segment"},{"ps":{"x":596.2464285714285,"y":438.1928571428571,"name":"point"},"pe":{"x":598.8,"y":437.8,"name":"point"},"name":"segment"},{"ps":{"x":598.8,"y":437.8,"name":"point"},"pe":{"x":599.8811403508773,"y":436.33728070175425,"name":"point"},"name":"segment"},{"ps":{"x":599.8811403508773,"y":436.33728070175425,"name":"point"},"pe":{"x":602.7764127764127,"y":429.43316953316935,"name":"point"},"name":"segment"},{"ps":{"x":602.7764127764127,"y":429.43316953316935,"name":"point"},"pe":{"x":602.2,"y":427.8,"name":"point"},"name":"segment"},{"ps":{"x":602.2,"y":427.8,"name":"point"},"pe":{"x":602.2,"y":425.5,"name":"point"},"name":"segment"},{"ps":{"x":602.2,"y":425.5,"name":"point"},"pe":{"x":602.7065743944636,"y":424.0647058823528,"name":"point"},"name":"segment"},{"ps":{"x":602.7065743944636,"y":424.0647058823528,"name":"point"},"pe":{"x":605.4,"y":425.7,"name":"point"},"name":"segment"},{"ps":{"x":605.4,"y":425.7,"name":"point"},"pe":{"x":604.8,"y":425.8,"name":"point"},"name":"segment"},{"ps":{"x":604.8,"y":425.8,"name":"point"},"pe":{"x":605.3161290322583,"y":426.02580645161305,"name":"point"},"name":"segment"},{"ps":{"x":605.3161290322583,"y":426.02580645161305,"name":"point"},"pe":{"x":605.8206896551726,"y":426.13793103448296,"name":"point"},"name":"segment"},{"ps":{"x":605.8206896551726,"y":426.13793103448296,"name":"point"},"pe":{"x":605.6,"y":426,"name":"point"},"name":"segment"},{"ps":{"x":605.6,"y":426,"name":"point"},"pe":{"x":607.4349083895853,"y":425.97261330761813,"name":"point"},"name":"segment"},{"ps":{"x":607.4349083895853,"y":425.97261330761813,"name":"point"},"pe":{"x":609.2,"y":426.8,"name":"point"},"name":"segment"},{"ps":{"x":609.2,"y":426.8,"name":"point"},"pe":{"x":609.8233025984912,"y":425.93696563285835,"name":"point"},"name":"segment"},{"ps":{"x":609.8233025984912,"y":425.93696563285835,"name":"point"},"pe":{"x":612.3,"y":425.9,"name":"point"},"name":"segment"},{"ps":{"x":612.3,"y":425.9,"name":"point"},"pe":{"x":613.3,"y":424,"name":"point"},"name":"segment"},{"ps":{"x":613.3,"y":424,"name":"point"},"pe":{"x":614.610344827586,"y":423.541379310345,"name":"point"},"name":"segment"},{"ps":{"x":614.610344827586,"y":423.541379310345,"name":"point"},"pe":{"x":614.8,"y":423.3,"name":"point"},"name":"segment"},{"ps":{"x":614.8,"y":423.3,"name":"point"},"pe":{"x":615.2200000000003,"y":423.32800000000003,"name":"point"},"name":"segment"},{"ps":{"x":615.2200000000003,"y":423.32800000000003,"name":"point"},"pe":{"x":615.3,"y":423.3,"name":"point"},"name":"segment"},{"ps":{"x":615.3,"y":423.3,"name":"point"},"pe":{"x":615.7051724137923,"y":423.3603448275862,"name":"point"},"name":"segment"},{"ps":{"x":615.7051724137923,"y":423.3603448275862,"name":"point"},"pe":{"x":620.4450381679391,"y":423.6763358778625,"name":"point"},"name":"segment"},{"ps":{"x":620.4450381679391,"y":423.6763358778625,"name":"point"},"pe":{"x":623.3,"y":421.6000000000001,"name":"point"},"name":"segment"},{"ps":{"x":623.3,"y":421.6000000000001,"name":"point"},"pe":{"x":625.3999999999997,"y":416.98,"name":"point"},"name":"segment"},{"ps":{"x":625.3999999999997,"y":416.98,"name":"point"},"pe":{"x":625.8,"y":416.5,"name":"point"},"name":"segment"},{"ps":{"x":625.8,"y":416.5,"name":"point"},"pe":{"x":627.5209302325579,"y":412.3139534883709,"name":"point"},"name":"segment"},{"ps":{"x":627.5209302325579,"y":412.3139534883709,"name":"point"},"pe":{"x":629.1474264705897,"y":408.73566176470115,"name":"point"},"name":"segment"},{"ps":{"x":629.1474264705897,"y":408.73566176470115,"name":"point"},"pe":{"x":629.4144013880857,"y":407.708212839792,"name":"point"},"name":"segment"},{"ps":{"x":629.4144013880857,"y":407.708212839792,"name":"point"},"pe":{"x":629.5,"y":407.5,"name":"point"},"name":"segment"},{"ps":{"x":629.5,"y":407.5,"name":"point"},"pe":{"x":629.4893858984078,"y":407.4196360879452,"name":"point"},"name":"segment"},{"ps":{"x":629.4893858984078,"y":407.4196360879452,"name":"point"},"pe":{"x":630.3,"y":404.3,"name":"point"},"name":"segment"},{"ps":{"x":630.3,"y":404.3,"name":"point"},"pe":{"x":633.3,"y":397,"name":"point"},"name":"segment"},{"ps":{"x":633.3,"y":397,"name":"point"},"pe":{"x":634.6,"y":396.74,"name":"point"},"name":"segment"},{"ps":{"x":634.6,"y":396.74,"name":"point"},"pe":{"x":634.8,"y":396.3,"name":"point"},"name":"segment"},{"ps":{"x":634.8,"y":396.3,"name":"point"},"pe":{"x":635.2472049689441,"y":396.61055900621113,"name":"point"},"name":"segment"},{"ps":{"x":635.2472049689441,"y":396.61055900621113,"name":"point"},"pe":{"x":635.3,"y":396.6,"name":"point"},"name":"segment"},{"ps":{"x":635.3,"y":396.6,"name":"point"},"pe":{"x":635.3136504014824,"y":396.65670166769615,"name":"point"},"name":"segment"},{"ps":{"x":635.3136504014824,"y":396.65670166769615,"name":"point"},"pe":{"x":635.8961248112734,"y":397.0611977856065,"name":"point"},"name":"segment"},{"ps":{"x":635.8961248112734,"y":397.0611977856065,"name":"point"},"pe":{"x":637.2,"y":402.2,"name":"point"},"name":"segment"},{"ps":{"x":637.2,"y":402.2,"name":"point"},"pe":{"x":637.8,"y":409.8,"name":"point"},"name":"segment"},{"ps":{"x":637.8,"y":409.8,"name":"point"},"pe":{"x":650.3633187772926,"y":407.1078602620087,"name":"point"},"name":"segment"},{"ps":{"x":650.3633187772926,"y":407.1078602620087,"name":"point"},"pe":{"x":652.8,"y":408.8,"name":"point"},"name":"segment"},{"ps":{"x":652.8,"y":408.8,"name":"point"},"pe":{"x":654.1391684901531,"y":411.7759299781182,"name":"point"},"name":"segment"},{"ps":{"x":654.1391684901531,"y":411.7759299781182,"name":"point"},"pe":{"x":653.8589003054708,"y":411.99025270758113,"name":"point"},"name":"segment"},{"ps":{"x":653.8589003054708,"y":411.99025270758113,"name":"point"},"pe":{"x":659.9,"y":424.9,"name":"point"},"name":"segment"},{"ps":{"x":659.9,"y":424.9,"name":"point"},"pe":{"x":660.1636363636363,"y":425.16363636363616,"name":"point"},"name":"segment"},{"ps":{"x":660.1636363636363,"y":425.16363636363616,"name":"point"},"pe":{"x":660.4747252747255,"y":425.8549450549451,"name":"point"},"name":"segment"},{"ps":{"x":660.4747252747255,"y":425.8549450549451,"name":"point"},"pe":{"x":660.95,"y":425.95,"name":"point"},"name":"segment"},{"ps":{"x":660.95,"y":425.95,"name":"point"},"pe":{"x":662.6285714285714,"y":427.62857142857126,"name":"point"},"name":"segment"},{"ps":{"x":662.6285714285714,"y":427.62857142857126,"name":"point"},"pe":{"x":662.8,"y":428.2,"name":"point"},"name":"segment"},{"ps":{"x":662.8,"y":428.2,"name":"point"},"pe":{"x":662.8,"y":428.5222222222222,"name":"point"},"name":"segment"},{"ps":{"x":662.8,"y":428.5222222222222,"name":"point"},"pe":{"x":663.3652173913043,"y":428.36521739130427,"name":"point"},"name":"segment"},{"ps":{"x":663.3652173913043,"y":428.36521739130427,"name":"point"},"pe":{"x":664.3,"y":429.3,"name":"point"},"name":"segment"},{"ps":{"x":664.3,"y":429.3,"name":"point"},"pe":{"x":666.7,"y":429.9,"name":"point"},"name":"segment"},{"ps":{"x":666.7,"y":429.9,"name":"point"},"pe":{"x":676.9880421243348,"y":424.80405390103044,"name":"point"},"name":"segment"},{"ps":{"x":676.9880421243348,"y":424.80405390103044,"name":"point"},"pe":{"x":677.0046511627908,"y":424.6,"name":"point"},"name":"segment"},{"ps":{"x":677.0046511627908,"y":424.6,"name":"point"},"pe":{"x":676.9199999999996,"y":424.6,"name":"point"},"name":"segment"},{"ps":{"x":676.9199999999996,"y":424.6,"name":"point"},"pe":{"x":677.0066093853271,"y":424.57594183740895,"name":"point"},"name":"segment"},{"ps":{"x":677.0066093853271,"y":424.57594183740895,"name":"point"},"pe":{"x":677.0326693227092,"y":424.2557768924303,"name":"point"},"name":"segment"},{"ps":{"x":677.0326693227092,"y":424.2557768924303,"name":"point"},"pe":{"x":679,"y":423.6,"name":"point"},"name":"segment"},{"ps":{"x":679,"y":423.6,"name":"point"},"pe":{"x":682.357482185273,"y":421.67707838479805,"name":"point"},"name":"segment"},{"ps":{"x":682.357482185273,"y":421.67707838479805,"name":"point"},"pe":{"x":682.8,"y":421.8,"name":"point"},"name":"segment"},{"ps":{"x":682.8,"y":421.8,"name":"point"},"pe":{"x":682.8180505415162,"y":421.8794223826715,"name":"point"},"name":"segment"},{"ps":{"x":682.8180505415162,"y":421.8794223826715,"name":"point"},"pe":{"x":687.5974683544301,"y":418.8379746835445,"name":"point"},"name":"segment"},{"ps":{"x":687.5974683544301,"y":418.8379746835445,"name":"point"},"pe":{"x":687.6086956521738,"y":418.66956521739127,"name":"point"},"name":"segment"},{"ps":{"x":687.6086956521738,"y":418.66956521739127,"name":"point"},"pe":{"x":690,"y":417.3,"name":"point"},"name":"segment"},{"ps":{"x":690,"y":417.3,"name":"point"},"pe":{"x":690.0055555555555,"y":417.30555555555554,"name":"point"},"name":"segment"},{"ps":{"x":690.0055555555555,"y":417.30555555555554,"name":"point"},"pe":{"x":690.8,"y":416.8,"name":"point"},"name":"segment"},{"ps":{"x":690.8,"y":416.8,"name":"point"},"pe":{"x":692.8728943338436,"y":417.77886676875954,"name":"point"},"name":"segment"},{"ps":{"x":692.8728943338436,"y":417.77886676875954,"name":"point"},"pe":{"x":693.5,"y":426.2,"name":"point"},"name":"segment"},{"ps":{"x":693.5,"y":426.2,"name":"point"},"pe":{"x":694.8,"y":428.5,"name":"point"},"name":"segment"},{"ps":{"x":694.8,"y":428.5,"name":"point"},"pe":{"x":695.5,"y":432.8,"name":"point"},"name":"segment"},{"ps":{"x":695.5,"y":432.8,"name":"point"},"pe":{"x":698.2,"y":432.8,"name":"point"},"name":"segment"},{"ps":{"x":698.2,"y":432.8,"name":"point"},"pe":{"x":704.9888039661226,"y":423.50026853955796,"name":"point"},"name":"segment"},{"ps":{"x":704.9888039661226,"y":423.50026853955796,"name":"point"},"pe":{"x":707.4083618917066,"y":424.64283755997263,"name":"point"},"name":"segment"},{"ps":{"x":707.4083618917066,"y":424.64283755997263,"name":"point"},"pe":{"x":708,"y":424,"name":"point"},"name":"segment"},{"ps":{"x":708,"y":424,"name":"point"},"pe":{"x":708,"y":424.9222222222223,"name":"point"},"name":"segment"},{"ps":{"x":708,"y":424.9222222222223,"name":"point"},"pe":{"x":708.8,"y":425.3,"name":"point"},"name":"segment"},{"ps":{"x":708.8,"y":425.3,"name":"point"},"pe":{"x":708.1976878612716,"y":429.2150289017341,"name":"point"},"name":"segment"},{"ps":{"x":708.1976878612716,"y":429.2150289017341,"name":"point"},"pe":{"x":707.5,"y":430.2,"name":"point"},"name":"segment"},{"ps":{"x":707.5,"y":430.2,"name":"point"},"pe":{"x":704.5,"y":433.2,"name":"point"},"name":"segment"},{"ps":{"x":704.5,"y":433.2,"name":"point"},"pe":{"x":703.2560975609756,"y":436.060975609756,"name":"point"},"name":"segment"},{"ps":{"x":703.2560975609756,"y":436.060975609756,"name":"point"},"pe":{"x":704.2222222222222,"y":437.8,"name":"point"},"name":"segment"},{"ps":{"x":704.2222222222222,"y":437.8,"name":"point"},"pe":{"x":706.8769230769229,"y":437.8,"name":"point"},"name":"segment"},{"ps":{"x":706.8769230769229,"y":437.8,"name":"point"},"pe":{"x":706.8,"y":438.3,"name":"point"},"name":"segment"},{"ps":{"x":706.8,"y":438.3,"name":"point"},"pe":{"x":709.1390862944162,"y":440.44416243654825,"name":"point"},"name":"segment"},{"ps":{"x":709.1390862944162,"y":440.44416243654825,"name":"point"},"pe":{"x":711.3,"y":441.6,"name":"point"},"name":"segment"},{"ps":{"x":711.3,"y":441.6,"name":"point"},"pe":{"x":714.2224376731302,"y":444.3470914127425,"name":"point"},"name":"segment"},{"ps":{"x":714.2224376731302,"y":444.3470914127425,"name":"point"},"pe":{"x":718.1776978417267,"y":445.86834532374104,"name":"point"},"name":"segment"},{"ps":{"x":718.1776978417267,"y":445.86834532374104,"name":"point"},"pe":{"x":721.853191489362,"y":445.02340425531924,"name":"point"},"name":"segment"},{"ps":{"x":721.853191489362,"y":445.02340425531924,"name":"point"},"pe":{"x":723.3,"y":444.3,"name":"point"},"name":"segment"},{"ps":{"x":723.3,"y":444.3,"name":"point"},"pe":{"x":724.4012145748989,"y":444.4376518218625,"name":"point"},"name":"segment"},{"ps":{"x":724.4012145748989,"y":444.4376518218625,"name":"point"},"pe":{"x":725,"y":444.3,"name":"point"},"name":"segment"},{"ps":{"x":725,"y":444.3,"name":"point"},"pe":{"x":730.3,"y":443.6,"name":"point"},"name":"segment"},{"ps":{"x":730.3,"y":443.6,"name":"point"},"pe":{"x":733.9156521739131,"y":445.62695652173926,"name":"point"},"name":"segment"},{"ps":{"x":733.9156521739131,"y":445.62695652173926,"name":"point"},"pe":{"x":735.3,"y":445.8,"name":"point"},"name":"segment"},{"ps":{"x":735.3,"y":445.8,"name":"point"},"pe":{"x":741.8,"y":445.8,"name":"point"},"name":"segment"},{"ps":{"x":741.8,"y":445.8,"name":"point"},"pe":{"x":742.1687969924812,"y":445.14436090225564,"name":"point"},"name":"segment"},{"ps":{"x":742.1687969924812,"y":445.14436090225564,"name":"point"},"pe":{"x":743.2345314505778,"y":445.62695763799746,"name":"point"},"name":"segment"},{"ps":{"x":743.2345314505778,"y":445.62695763799746,"name":"point"},"pe":{"x":743.3,"y":445.6,"name":"point"},"name":"segment"},{"ps":{"x":743.3,"y":445.6,"name":"point"},"pe":{"x":744.419018404908,"y":445.3901840490798,"name":"point"},"name":"segment"},{"ps":{"x":744.419018404908,"y":445.3901840490798,"name":"point"},"pe":{"x":744.2,"y":443.2,"name":"point"},"name":"segment"},{"ps":{"x":744.2,"y":443.2,"name":"point"},"pe":{"x":743.9540983606557,"y":441.9704918032786,"name":"point"},"name":"segment"},{"ps":{"x":743.9540983606557,"y":441.9704918032786,"name":"point"},"pe":{"x":744.6422857142858,"y":440.7470476190477,"name":"point"},"name":"segment"},{"ps":{"x":744.6422857142858,"y":440.7470476190477,"name":"point"},"pe":{"x":744.6,"y":440,"name":"point"},"name":"segment"},{"ps":{"x":744.6,"y":440,"name":"point"},"pe":{"x":745.6,"y":438.3,"name":"point"},"name":"segment"},{"ps":{"x":745.6,"y":438.3,"name":"point"},"pe":{"x":746.0498233215546,"y":438.24475853945813,"name":"point"},"name":"segment"},{"ps":{"x":746.0498233215546,"y":438.24475853945813,"name":"point"},"pe":{"x":746.3,"y":437.8,"name":"point"},"name":"segment"},{"ps":{"x":746.3,"y":437.8,"name":"point"},"pe":{"x":747.0298969072162,"y":438.1243986254295,"name":"point"},"name":"segment"},{"ps":{"x":747.0298969072162,"y":438.1243986254295,"name":"point"},"pe":{"x":751.3,"y":437.6,"name":"point"},"name":"segment"},{"ps":{"x":751.3,"y":437.6,"name":"point"},"pe":{"x":751.3,"y":439.96666666666664,"name":"point"},"name":"segment"},{"ps":{"x":751.3,"y":439.96666666666664,"name":"point"},"pe":{"x":753.1612903225806,"y":440.5870967741936,"name":"point"},"name":"segment"},{"ps":{"x":753.1612903225806,"y":440.5870967741936,"name":"point"},"pe":{"x":752.8,"y":444.2,"name":"point"},"name":"segment"},{"ps":{"x":752.8,"y":444.2,"name":"point"},"pe":{"x":757.2,"y":446.2,"name":"point"},"name":"segment"},{"ps":{"x":757.2,"y":446.2,"name":"point"},"pe":{"x":758.9810559006212,"y":447.5654761904762,"name":"point"},"name":"segment"},{"ps":{"x":758.9810559006212,"y":447.5654761904762,"name":"point"},"pe":{"x":761.3838747099769,"y":446.5420533642691,"name":"point"},"name":"segment"},{"ps":{"x":761.3838747099769,"y":446.5420533642691,"name":"point"},"pe":{"x":762.8,"y":444.2,"name":"point"},"name":"segment"},{"ps":{"x":762.8,"y":444.2,"name":"point"},"pe":{"x":763.3454545454546,"y":443.9818181818182,"name":"point"},"name":"segment"},{"ps":{"x":763.3454545454546,"y":443.9818181818182,"name":"point"},"pe":{"x":764.3,"y":444.3,"name":"point"},"name":"segment"},{"ps":{"x":764.3,"y":444.3,"name":"point"},"pe":{"x":764.3,"y":445.3,"name":"point"},"name":"segment"},{"ps":{"x":764.3,"y":445.3,"name":"point"},"pe":{"x":765.6,"y":445.3,"name":"point"},"name":"segment"},{"ps":{"x":765.6,"y":445.3,"name":"point"},"pe":{"x":764.9,"y":449,"name":"point"},"name":"segment"},{"ps":{"x":764.9,"y":449,"name":"point"},"pe":{"x":764.6,"y":453.3,"name":"point"},"name":"segment"},{"ps":{"x":764.6,"y":453.3,"name":"point"},"pe":{"x":766.9,"y":454,"name":"point"},"name":"segment"},{"ps":{"x":766.9,"y":454,"name":"point"},"pe":{"x":780.2496868475996,"y":455.45302713987485,"name":"point"},"name":"segment"},{"ps":{"x":780.2496868475996,"y":455.45302713987485,"name":"point"},"pe":{"x":786.8,"y":457.5,"name":"point"},"name":"segment"},{"ps":{"x":786.8,"y":457.5,"name":"point"},"pe":{"x":785.5,"y":458.5,"name":"point"},"name":"segment"},{"ps":{"x":785.5,"y":458.5,"name":"point"},"pe":{"x":782.5,"y":458.5,"name":"point"},"name":"segment"},{"ps":{"x":782.5,"y":458.5,"name":"point"},"pe":{"x":757.1344066237349,"y":460.2519779208832,"name":"point"},"name":"segment"},{"ps":{"x":757.1344066237349,"y":460.2519779208832,"name":"point"},"pe":{"x":748.3,"y":460.6,"name":"point"},"name":"segment"},{"ps":{"x":748.3,"y":460.6,"name":"point"},"pe":{"x":725.3,"y":460.3,"name":"point"},"name":"segment"},{"ps":{"x":725.3,"y":460.3,"name":"point"},"pe":{"x":645.6,"y":462,"name":"point"},"name":"segment"},{"ps":{"x":645.6,"y":462,"name":"point"},"pe":{"x":622.4,"y":462.3,"name":"point"},"name":"segment"},{"ps":{"x":622.4,"y":462.3,"name":"point"},"pe":{"x":605,"y":464.3,"name":"point"},"name":"segment"},{"ps":{"x":605,"y":464.3,"name":"point"},"pe":{"x":567.7751724137913,"y":465.0158620689656,"name":"point"},"name":"segment"},{"ps":{"x":567.7751724137913,"y":465.0158620689656,"name":"point"},"pe":{"x":563.3,"y":465.3,"name":"point"},"name":"segment"},{"ps":{"x":563.3,"y":465.3,"name":"point"},"pe":{"x":524.3033434650456,"y":469.88784194528876,"name":"point"},"name":"segment"},{"ps":{"x":524.3033434650456,"y":469.88784194528876,"name":"point"},"pe":{"x":524.2,"y":469.8,"name":"point"},"name":"segment"},{"ps":{"x":524.2,"y":469.8,"name":"point"},"pe":{"x":520.0857142857142,"y":469.8,"name":"point"},"name":"segment"},{"ps":{"x":520.0857142857142,"y":469.8,"name":"point"},"pe":{"x":515.8,"y":466.8,"name":"point"},"name":"segment"},{"ps":{"x":515.8,"y":466.8,"name":"point"},"pe":{"x":514.7151219512195,"y":466.4609756097562,"name":"point"},"name":"segment"},{"ps":{"x":514.7151219512195,"y":466.4609756097562,"name":"point"},"pe":{"x":514.5186785260483,"y":466.04002541296063,"name":"point"},"name":"segment"},{"ps":{"x":514.5186785260483,"y":466.04002541296063,"name":"point"},"pe":{"x":513.4347826086957,"y":466.0608695652174,"name":"point"},"name":"segment"},{"ps":{"x":513.4347826086957,"y":466.0608695652174,"name":"point"},"pe":{"x":509.7435528500277,"y":464.90736026563366,"name":"point"},"name":"segment"},{"ps":{"x":509.7435528500277,"y":464.90736026563366,"name":"point"},"pe":{"x":508.5535239810852,"y":466.1547399234408,"name":"point"},"name":"segment"},{"ps":{"x":508.5535239810852,"y":466.1547399234408,"name":"point"},"pe":{"x":506.1709497206705,"y":466.2005586592179,"name":"point"},"name":"segment"},{"ps":{"x":506.1709497206705,"y":466.2005586592179,"name":"point"},"pe":{"x":501.8,"y":471.3,"name":"point"},"name":"segment"},{"ps":{"x":501.8,"y":471.3,"name":"point"},"pe":{"x":496.3,"y":470.3,"name":"point"},"name":"segment"},{"ps":{"x":496.3,"y":470.3,"name":"point"},"pe":{"x":491.8,"y":476.8,"name":"point"},"name":"segment"},{"ps":{"x":491.8,"y":476.8,"name":"point"},"pe":{"x":487.24683544303804,"y":480.52531645569616,"name":"point"},"name":"segment"},{"ps":{"x":487.24683544303804,"y":480.52531645569616,"name":"point"},"pe":{"x":485.39595375722547,"y":480.7104046242774,"name":"point"},"name":"segment"},{"ps":{"x":485.39595375722547,"y":480.7104046242774,"name":"point"},"pe":{"x":474.8,"y":473.8,"name":"point"},"name":"segment"},{"ps":{"x":474.8,"y":473.8,"name":"point"},"pe":{"x":493.8,"y":460.3,"name":"point"},"name":"segment"},{"ps":{"x":493.8,"y":460.3,"name":"point"},"pe":{"x":489.8,"y":454.8,"name":"point"},"name":"segment"},{"ps":{"x":489.8,"y":454.8,"name":"point"},"pe":{"x":490.286346300534,"y":453.2193745232649,"name":"point"},"name":"segment"},{"ps":{"x":490.286346300534,"y":453.2193745232649,"name":"point"},"pe":{"x":489.3,"y":451.6,"name":"point"},"name":"segment"},{"ps":{"x":489.3,"y":451.6,"name":"point"},"pe":{"x":491.0807980049874,"y":450.63740648379087,"name":"point"},"name":"segment"},{"ps":{"x":491.0807980049874,"y":450.63740648379087,"name":"point"},"pe":{"x":491.7792207792208,"y":448.36753246753244,"name":"point"},"name":"segment"},{"ps":{"x":491.7792207792208,"y":448.36753246753244,"name":"point"},"pe":{"x":492.5,"y":448.8,"name":"point"},"name":"segment"},{"ps":{"x":492.5,"y":448.8,"name":"point"},"pe":{"x":495.6999999999999,"y":449.6,"name":"point"},"name":"segment"}],[{"ps":{"x":611.372463768116,"y":427.6623188405795,"name":"point"},"pe":{"x":612.7571428571428,"y":425.9,"name":"point"},"name":"segment"},{"ps":{"x":612.7571428571428,"y":425.9,"name":"point"},"pe":{"x":612.3,"y":425.9,"name":"point"},"name":"segment"},{"ps":{"x":612.3,"y":425.9,"name":"point"},"pe":{"x":611.372463768116,"y":427.6623188405795,"name":"point"},"name":"segment"}]]`;
            //const json2 = `[[{"ps":{"x":495.6999999999999,"y":449.6,"name":"point"},"pe":{"x":496.5,"y":449.8,"name":"point"},"name":"segment"},{"ps":{"x":496.5,"y":449.8,"name":"point"},"pe":{"x":497.8,"y":451.2,"name":"point"},"name":"segment"},{"ps":{"x":497.8,"y":451.2,"name":"point"},"pe":{"x":500.62352941176465,"y":449.6,"name":"point"},"name":"segment"},{"ps":{"x":500.62352941176465,"y":449.6,"name":"point"},"pe":{"x":504.3,"y":449.6,"name":"point"},"name":"segment"},{"ps":{"x":504.3,"y":449.6,"name":"point"},"pe":{"x":509.7,"y":448.3,"name":"point"},"name":"segment"},{"ps":{"x":509.7,"y":448.3,"name":"point"},"pe":{"x":510.16305569749636,"y":447.76647930505874,"name":"point"},"name":"segment"},{"ps":{"x":510.16305569749636,"y":447.76647930505874,"name":"point"},"pe":{"x":511.8,"y":447.5,"name":"point"},"name":"segment"},{"ps":{"x":511.8,"y":447.5,"name":"point"},"pe":{"x":512.0000000000002,"y":445.64999999999986,"name":"point"},"name":"segment"},{"ps":{"x":512.0000000000002,"y":445.64999999999986,"name":"point"},"pe":{"x":514.3,"y":443,"name":"point"},"name":"segment"},{"ps":{"x":514.3,"y":443,"name":"point"},"pe":{"x":522.3,"y":427.6,"name":"point"},"name":"segment"},{"ps":{"x":522.3,"y":427.6,"name":"point"},"pe":{"x":525,"y":426,"name":"point"},"name":"segment"},{"ps":{"x":525,"y":426,"name":"point"},"pe":{"x":527,"y":419.6,"name":"point"},"name":"segment"},{"ps":{"x":527,"y":419.6,"name":"point"},"pe":{"x":536.3,"y":419.3,"name":"point"},"name":"segment"},{"ps":{"x":536.3,"y":419.3,"name":"point"},"pe":{"x":536.3,"y":420.3,"name":"point"},"name":"segment"},{"ps":{"x":536.3,"y":420.3,"name":"point"},"pe":{"x":535.7,"y":421.6,"name":"point"},"name":"segment"},{"ps":{"x":535.7,"y":421.6,"name":"point"},"pe":{"x":533,"y":425.3,"name":"point"},"name":"segment"},{"ps":{"x":533,"y":425.3,"name":"point"},"pe":{"x":533,"y":431,"name":"point"},"name":"segment"},{"ps":{"x":533,"y":431,"name":"point"},"pe":{"x":531.7,"y":433.6,"name":"point"},"name":"segment"},{"ps":{"x":531.7,"y":433.6,"name":"point"},"pe":{"x":533.3,"y":438.6,"name":"point"},"name":"segment"},{"ps":{"x":533.3,"y":438.6,"name":"point"},"pe":{"x":534.74578313253,"y":439.0915662650602,"name":"point"},"name":"segment"},{"ps":{"x":534.74578313253,"y":439.0915662650602,"name":"point"},"pe":{"x":534.8,"y":439.2,"name":"point"},"name":"segment"},{"ps":{"x":534.8,"y":439.2,"name":"point"},"pe":{"x":534.9610738255034,"y":439.1647651006711,"name":"point"},"name":"segment"},{"ps":{"x":534.9610738255034,"y":439.1647651006711,"name":"point"},"pe":{"x":538.3,"y":440.3,"name":"point"},"name":"segment"},{"ps":{"x":538.3,"y":440.3,"name":"point"},"pe":{"x":547.1,"y":439.6,"name":"point"},"name":"segment"},{"ps":{"x":547.1,"y":439.6,"name":"point"},"pe":{"x":550.9,"y":438,"name":"point"},"name":"segment"},{"ps":{"x":550.9,"y":438,"name":"point"},"pe":{"x":549.7,"y":438.3,"name":"point"},"name":"segment"},{"ps":{"x":549.7,"y":438.3,"name":"point"},"pe":{"x":553,"y":435.6,"name":"point"},"name":"segment"},{"ps":{"x":553,"y":435.6,"name":"point"},"pe":{"x":557.7,"y":435.6,"name":"point"},"name":"segment"},{"ps":{"x":557.7,"y":435.6,"name":"point"},"pe":{"x":559.7,"y":432.6,"name":"point"},"name":"segment"},{"ps":{"x":559.7,"y":432.6,"name":"point"},"pe":{"x":561.3,"y":432.6,"name":"point"},"name":"segment"},{"ps":{"x":561.3,"y":432.6,"name":"point"},"pe":{"x":563.7,"y":433.6,"name":"point"},"name":"segment"},{"ps":{"x":563.7,"y":433.6,"name":"point"},"pe":{"x":565.5,"y":434.7,"name":"point"},"name":"segment"},{"ps":{"x":565.5,"y":434.7,"name":"point"},"pe":{"x":566.6864516129033,"y":434.43634408602156,"name":"point"},"name":"segment"},{"ps":{"x":566.6864516129033,"y":434.43634408602156,"name":"point"},"pe":{"x":566.8,"y":434.5,"name":"point"},"name":"segment"},{"ps":{"x":566.8,"y":434.5,"name":"point"},"pe":{"x":566.8888888888888,"y":434.3913580246913,"name":"point"},"name":"segment"},{"ps":{"x":566.8888888888888,"y":434.3913580246913,"name":"point"},"pe":{"x":570,"y":433.7,"name":"point"},"name":"segment"},{"ps":{"x":570,"y":433.7,"name":"point"},"pe":{"x":571.7,"y":431.6,"name":"point"},"name":"segment"},{"ps":{"x":571.7,"y":431.6,"name":"point"},"pe":{"x":572.3,"y":427,"name":"point"},"name":"segment"},{"ps":{"x":572.3,"y":427,"name":"point"},"pe":{"x":571,"y":422,"name":"point"},"name":"segment"},{"ps":{"x":571,"y":422,"name":"point"},"pe":{"x":571.7,"y":419.6,"name":"point"},"name":"segment"},{"ps":{"x":571.7,"y":419.6,"name":"point"},"pe":{"x":574.7,"y":419,"name":"point"},"name":"segment"},{"ps":{"x":574.7,"y":419,"name":"point"},"pe":{"x":575.7,"y":420,"name":"point"},"name":"segment"},{"ps":{"x":575.7,"y":420,"name":"point"},"pe":{"x":578,"y":426.3,"name":"point"},"name":"segment"},{"ps":{"x":578,"y":426.3,"name":"point"},"pe":{"x":580.3,"y":426.3,"name":"point"},"name":"segment"},{"ps":{"x":580.3,"y":426.3,"name":"point"},"pe":{"x":586.3,"y":423.3,"name":"point"},"name":"segment"},{"ps":{"x":586.3,"y":423.3,"name":"point"},"pe":{"x":594.3,"y":420.3,"name":"point"},"name":"segment"},{"ps":{"x":594.3,"y":420.3,"name":"point"},"pe":{"x":596.6,"y":423,"name":"point"},"name":"segment"},{"ps":{"x":596.6,"y":423,"name":"point"},"pe":{"x":596.7947261663286,"y":423.03245436105476,"name":"point"},"name":"segment"},{"ps":{"x":596.7947261663286,"y":423.03245436105476,"name":"point"},"pe":{"x":593.5,"y":429.8,"name":"point"},"name":"segment"},{"ps":{"x":593.5,"y":429.8,"name":"point"},"pe":{"x":595.5,"y":435.5,"name":"point"},"name":"segment"},{"ps":{"x":595.5,"y":435.5,"name":"point"},"pe":{"x":596.2,"y":438.2,"name":"point"},"name":"segment"},{"ps":{"x":596.2,"y":438.2,"name":"point"},"pe":{"x":598.8,"y":437.8,"name":"point"},"name":"segment"},{"ps":{"x":598.8,"y":437.8,"name":"point"},"pe":{"x":600.5,"y":435.5,"name":"point"},"name":"segment"},{"ps":{"x":600.5,"y":435.5,"name":"point"},"pe":{"x":602.8,"y":429.5,"name":"point"},"name":"segment"},{"ps":{"x":602.8,"y":429.5,"name":"point"},"pe":{"x":602.2,"y":427.8,"name":"point"},"name":"segment"},{"ps":{"x":602.2,"y":427.8,"name":"point"},"pe":{"x":602.2,"y":425.5,"name":"point"},"name":"segment"},{"ps":{"x":602.2,"y":425.5,"name":"point"},"pe":{"x":602.7065743944636,"y":424.0647058823528,"name":"point"},"name":"segment"},{"ps":{"x":602.7065743944636,"y":424.0647058823528,"name":"point"},"pe":{"x":605.4,"y":425.7,"name":"point"},"name":"segment"},{"ps":{"x":605.4,"y":425.7,"name":"point"},"pe":{"x":604.8,"y":425.8,"name":"point"},"name":"segment"},{"ps":{"x":604.8,"y":425.8,"name":"point"},"pe":{"x":606.4,"y":426.5,"name":"point"},"name":"segment"},{"ps":{"x":606.4,"y":426.5,"name":"point"},"pe":{"x":605.6,"y":426,"name":"point"},"name":"segment"},{"ps":{"x":605.6,"y":426,"name":"point"},"pe":{"x":607.4349083895853,"y":425.97261330761813,"name":"point"},"name":"segment"},{"ps":{"x":607.4349083895853,"y":425.97261330761813,"name":"point"},"pe":{"x":609.2,"y":426.8,"name":"point"},"name":"segment"},{"ps":{"x":609.2,"y":426.8,"name":"point"},"pe":{"x":609.8233025984912,"y":425.93696563285835,"name":"point"},"name":"segment"},{"ps":{"x":609.8233025984912,"y":425.93696563285835,"name":"point"},"pe":{"x":612.3,"y":425.9,"name":"point"},"name":"segment"},{"ps":{"x":612.3,"y":425.9,"name":"point"},"pe":{"x":613.3,"y":424,"name":"point"},"name":"segment"},{"ps":{"x":613.3,"y":424,"name":"point"},"pe":{"x":615.3,"y":423.3,"name":"point"},"name":"segment"},{"ps":{"x":615.3,"y":423.3,"name":"point"},"pe":{"x":620,"y":424,"name":"point"},"name":"segment"},{"ps":{"x":620,"y":424,"name":"point"},"pe":{"x":623.3,"y":421.6,"name":"point"},"name":"segment"},{"ps":{"x":623.3,"y":421.6,"name":"point"},"pe":{"x":627,"y":417,"name":"point"},"name":"segment"},{"ps":{"x":627,"y":417,"name":"point"},"pe":{"x":629.4144013880857,"y":407.708212839792,"name":"point"},"name":"segment"},{"ps":{"x":629.4144013880857,"y":407.708212839792,"name":"point"},"pe":{"x":629.5,"y":407.5,"name":"point"},"name":"segment"},{"ps":{"x":629.5,"y":407.5,"name":"point"},"pe":{"x":629.4893858984078,"y":407.4196360879452,"name":"point"},"name":"segment"},{"ps":{"x":629.4893858984078,"y":407.4196360879452,"name":"point"},"pe":{"x":630.3,"y":404.3,"name":"point"},"name":"segment"},{"ps":{"x":630.3,"y":404.3,"name":"point"},"pe":{"x":633.3,"y":397,"name":"point"},"name":"segment"},{"ps":{"x":633.3,"y":397,"name":"point"},"pe":{"x":635.3,"y":396.6,"name":"point"},"name":"segment"},{"ps":{"x":635.3,"y":396.6,"name":"point"},"pe":{"x":636.6,"y":402,"name":"point"},"name":"segment"},{"ps":{"x":636.6,"y":402,"name":"point"},"pe":{"x":637.6,"y":411,"name":"point"},"name":"segment"},{"ps":{"x":637.6,"y":411,"name":"point"},"pe":{"x":651,"y":407.6,"name":"point"},"name":"segment"},{"ps":{"x":651,"y":407.6,"name":"point"},"pe":{"x":652.6,"y":409.3,"name":"point"},"name":"segment"},{"ps":{"x":652.6,"y":409.3,"name":"point"},"pe":{"x":653.8589003054707,"y":411.9902527075812,"name":"point"},"name":"segment"},{"ps":{"x":653.8589003054707,"y":411.9902527075812,"name":"point"},"pe":{"x":652.8,"y":412.8,"name":"point"},"name":"segment"},{"ps":{"x":652.8,"y":412.8,"name":"point"},"pe":{"x":650.2,"y":412.8,"name":"point"},"name":"segment"},{"ps":{"x":650.2,"y":412.8,"name":"point"},"pe":{"x":637.5,"y":415.5,"name":"point"},"name":"segment"},{"ps":{"x":637.5,"y":415.5,"name":"point"},"pe":{"x":631.8,"y":418.2,"name":"point"},"name":"segment"},{"ps":{"x":631.8,"y":418.2,"name":"point"},"pe":{"x":624.8,"y":426.2,"name":"point"},"name":"segment"},{"ps":{"x":624.8,"y":426.2,"name":"point"},"pe":{"x":622.2,"y":428.2,"name":"point"},"name":"segment"},{"ps":{"x":622.2,"y":428.2,"name":"point"},"pe":{"x":620.5,"y":430.2,"name":"point"},"name":"segment"},{"ps":{"x":620.5,"y":430.2,"name":"point"},"pe":{"x":617.8,"y":432.5,"name":"point"},"name":"segment"},{"ps":{"x":617.8,"y":432.5,"name":"point"},"pe":{"x":614.5,"y":435.8,"name":"point"},"name":"segment"},{"ps":{"x":614.5,"y":435.8,"name":"point"},"pe":{"x":619.5,"y":435.8,"name":"point"},"name":"segment"},{"ps":{"x":619.5,"y":435.8,"name":"point"},"pe":{"x":621.5,"y":437.5,"name":"point"},"name":"segment"},{"ps":{"x":621.5,"y":437.5,"name":"point"},"pe":{"x":624.5,"y":440.8,"name":"point"},"name":"segment"},{"ps":{"x":624.5,"y":440.8,"name":"point"},"pe":{"x":627.2,"y":440.8,"name":"point"},"name":"segment"},{"ps":{"x":627.2,"y":440.8,"name":"point"},"pe":{"x":629.5,"y":439.2,"name":"point"},"name":"segment"},{"ps":{"x":629.5,"y":439.2,"name":"point"},"pe":{"x":631.5,"y":438.8,"name":"point"},"name":"segment"},{"ps":{"x":631.5,"y":438.8,"name":"point"},"pe":{"x":633.8,"y":439.5,"name":"point"},"name":"segment"},{"ps":{"x":633.8,"y":439.5,"name":"point"},"pe":{"x":635.2,"y":442.5,"name":"point"},"name":"segment"},{"ps":{"x":635.2,"y":442.5,"name":"point"},"pe":{"x":638.8,"y":445.2,"name":"point"},"name":"segment"},{"ps":{"x":638.8,"y":445.2,"name":"point"},"pe":{"x":642.8,"y":445.2,"name":"point"},"name":"segment"},{"ps":{"x":642.8,"y":445.2,"name":"point"},"pe":{"x":645.8,"y":444.2,"name":"point"},"name":"segment"},{"ps":{"x":645.8,"y":444.2,"name":"point"},"pe":{"x":649.5,"y":443.8,"name":"point"},"name":"segment"},{"ps":{"x":649.5,"y":443.8,"name":"point"},"pe":{"x":654.2,"y":432.8,"name":"point"},"name":"segment"},{"ps":{"x":654.2,"y":432.8,"name":"point"},"pe":{"x":654.2,"y":429.8,"name":"point"},"name":"segment"},{"ps":{"x":654.2,"y":429.8,"name":"point"},"pe":{"x":658.2,"y":426.2,"name":"point"},"name":"segment"},{"ps":{"x":658.2,"y":426.2,"name":"point"},"pe":{"x":660.2,"y":425.8,"name":"point"},"name":"segment"},{"ps":{"x":660.2,"y":425.8,"name":"point"},"pe":{"x":660.95,"y":425.95,"name":"point"},"name":"segment"},{"ps":{"x":660.95,"y":425.95,"name":"point"},"pe":{"x":662.6285714285714,"y":427.62857142857126,"name":"point"},"name":"segment"},{"ps":{"x":662.6285714285714,"y":427.62857142857126,"name":"point"},"pe":{"x":662.8,"y":428.2,"name":"point"},"name":"segment"},{"ps":{"x":662.8,"y":428.2,"name":"point"},"pe":{"x":662.8,"y":430.5,"name":"point"},"name":"segment"},{"ps":{"x":662.8,"y":430.5,"name":"point"},"pe":{"x":658.8,"y":433.5,"name":"point"},"name":"segment"},{"ps":{"x":658.8,"y":433.5,"name":"point"},"pe":{"x":656.2,"y":443.2,"name":"point"},"name":"segment"},{"ps":{"x":656.2,"y":443.2,"name":"point"},"pe":{"x":664.2,"y":443.2,"name":"point"},"name":"segment"},{"ps":{"x":664.2,"y":443.2,"name":"point"},"pe":{"x":669.2,"y":441.8,"name":"point"},"name":"segment"},{"ps":{"x":669.2,"y":441.8,"name":"point"},"pe":{"x":672.5,"y":438.8,"name":"point"},"name":"segment"},{"ps":{"x":672.5,"y":438.8,"name":"point"},"pe":{"x":676.5,"y":430.8,"name":"point"},"name":"segment"},{"ps":{"x":676.5,"y":430.8,"name":"point"},"pe":{"x":676.9880421243348,"y":424.8040539010306,"name":"point"},"name":"segment"},{"ps":{"x":676.9880421243348,"y":424.8040539010306,"name":"point"},"pe":{"x":677.4,"y":424.6,"name":"point"},"name":"segment"},{"ps":{"x":677.4,"y":424.6,"name":"point"},"pe":{"x":677.0046511627908,"y":424.6,"name":"point"},"name":"segment"},{"ps":{"x":677.0046511627908,"y":424.6,"name":"point"},"pe":{"x":677.0326693227092,"y":424.2557768924303,"name":"point"},"name":"segment"},{"ps":{"x":677.0326693227092,"y":424.2557768924303,"name":"point"},"pe":{"x":679,"y":423.6,"name":"point"},"name":"segment"},{"ps":{"x":679,"y":423.6,"name":"point"},"pe":{"x":682.357482185273,"y":421.67707838479805,"name":"point"},"name":"segment"},{"ps":{"x":682.357482185273,"y":421.67707838479805,"name":"point"},"pe":{"x":682.8,"y":421.8,"name":"point"},"name":"segment"},{"ps":{"x":682.8,"y":421.8,"name":"point"},"pe":{"x":683.8,"y":426.2,"name":"point"},"name":"segment"},{"ps":{"x":683.8,"y":426.2,"name":"point"},"pe":{"x":685.5,"y":426.2,"name":"point"},"name":"segment"},{"ps":{"x":685.5,"y":426.2,"name":"point"},"pe":{"x":687.2,"y":424.8,"name":"point"},"name":"segment"},{"ps":{"x":687.2,"y":424.8,"name":"point"},"pe":{"x":687.6086956521738,"y":418.66956521739127,"name":"point"},"name":"segment"},{"ps":{"x":687.6086956521738,"y":418.66956521739127,"name":"point"},"pe":{"x":690,"y":417.3,"name":"point"},"name":"segment"},{"ps":{"x":690,"y":417.3,"name":"point"},"pe":{"x":691.3,"y":418.6,"name":"point"},"name":"segment"},{"ps":{"x":691.3,"y":418.6,"name":"point"},"pe":{"x":692.1,"y":424.3,"name":"point"},"name":"segment"},{"ps":{"x":692.1,"y":424.3,"name":"point"},"pe":{"x":691.8,"y":424.3,"name":"point"},"name":"segment"},{"ps":{"x":691.8,"y":424.3,"name":"point"},"pe":{"x":692.6,"y":425.3,"name":"point"},"name":"segment"},{"ps":{"x":692.6,"y":425.3,"name":"point"},"pe":{"x":694.3,"y":433.6,"name":"point"},"name":"segment"},{"ps":{"x":694.3,"y":433.6,"name":"point"},"pe":{"x":697.6,"y":435.3,"name":"point"},"name":"segment"},{"ps":{"x":697.6,"y":435.3,"name":"point"},"pe":{"x":708,"y":424,"name":"point"},"name":"segment"},{"ps":{"x":708,"y":424,"name":"point"},"pe":{"x":708,"y":426.3,"name":"point"},"name":"segment"},{"ps":{"x":708,"y":426.3,"name":"point"},"pe":{"x":703,"y":435.6,"name":"point"},"name":"segment"},{"ps":{"x":703,"y":435.6,"name":"point"},"pe":{"x":703.2560975609756,"y":436.060975609756,"name":"point"},"name":"segment"},{"ps":{"x":703.2560975609756,"y":436.060975609756,"name":"point"},"pe":{"x":702.5,"y":437.8,"name":"point"},"name":"segment"},{"ps":{"x":702.5,"y":437.8,"name":"point"},"pe":{"x":704.2222222222222,"y":437.8,"name":"point"},"name":"segment"},{"ps":{"x":704.2222222222222,"y":437.8,"name":"point"},"pe":{"x":704.5,"y":438.3,"name":"point"},"name":"segment"},{"ps":{"x":704.5,"y":438.3,"name":"point"},"pe":{"x":707,"y":439.3,"name":"point"},"name":"segment"},{"ps":{"x":707,"y":439.3,"name":"point"},"pe":{"x":711.3,"y":441.6,"name":"point"},"name":"segment"},{"ps":{"x":711.3,"y":441.6,"name":"point"},"pe":{"x":716.3,"y":446.3,"name":"point"},"name":"segment"},{"ps":{"x":716.3,"y":446.3,"name":"point"},"pe":{"x":725,"y":444.3,"name":"point"},"name":"segment"},{"ps":{"x":725,"y":444.3,"name":"point"},"pe":{"x":730.3,"y":443.6,"name":"point"},"name":"segment"},{"ps":{"x":730.3,"y":443.6,"name":"point"},"pe":{"x":736.9,"y":447.3,"name":"point"},"name":"segment"},{"ps":{"x":736.9,"y":447.3,"name":"point"},"pe":{"x":739.9,"y":447,"name":"point"},"name":"segment"},{"ps":{"x":739.9,"y":447,"name":"point"},"pe":{"x":743.2345314505777,"y":445.62695763799746,"name":"point"},"name":"segment"},{"ps":{"x":743.2345314505777,"y":445.62695763799746,"name":"point"},"pe":{"x":744.5,"y":446.2,"name":"point"},"name":"segment"},{"ps":{"x":744.5,"y":446.2,"name":"point"},"pe":{"x":744.419018404908,"y":445.3901840490798,"name":"point"},"name":"segment"},{"ps":{"x":744.419018404908,"y":445.3901840490798,"name":"point"},"pe":{"x":744.9,"y":445.3,"name":"point"},"name":"segment"},{"ps":{"x":744.9,"y":445.3,"name":"point"},"pe":{"x":744.6,"y":440,"name":"point"},"name":"segment"},{"ps":{"x":744.6,"y":440,"name":"point"},"pe":{"x":745.6,"y":438.3,"name":"point"},"name":"segment"},{"ps":{"x":745.6,"y":438.3,"name":"point"},"pe":{"x":751.3,"y":437.6,"name":"point"},"name":"segment"},{"ps":{"x":751.3,"y":437.6,"name":"point"},"pe":{"x":751.3,"y":446,"name":"point"},"name":"segment"},{"ps":{"x":751.3,"y":446,"name":"point"},"pe":{"x":758.9,"y":447.6,"name":"point"},"name":"segment"},{"ps":{"x":758.9,"y":447.6,"name":"point"},"pe":{"x":758.9810559006212,"y":447.5654761904762,"name":"point"},"name":"segment"},{"ps":{"x":758.9810559006212,"y":447.5654761904762,"name":"point"},"pe":{"x":760.2,"y":448.5,"name":"point"},"name":"segment"},{"ps":{"x":760.2,"y":448.5,"name":"point"},"pe":{"x":761.3838747099769,"y":446.5420533642691,"name":"point"},"name":"segment"},{"ps":{"x":761.3838747099769,"y":446.5420533642691,"name":"point"},"pe":{"x":764.3,"y":445.3,"name":"point"},"name":"segment"},{"ps":{"x":764.3,"y":445.3,"name":"point"},"pe":{"x":765.6,"y":445.3,"name":"point"},"name":"segment"},{"ps":{"x":765.6,"y":445.3,"name":"point"},"pe":{"x":764.9,"y":449,"name":"point"},"name":"segment"},{"ps":{"x":764.9,"y":449,"name":"point"},"pe":{"x":764.6,"y":453.3,"name":"point"},"name":"segment"},{"ps":{"x":764.6,"y":453.3,"name":"point"},"pe":{"x":766.9,"y":454,"name":"point"},"name":"segment"},{"ps":{"x":766.9,"y":454,"name":"point"},"pe":{"x":780.2496868475996,"y":455.45302713987485,"name":"point"},"name":"segment"},{"ps":{"x":780.2496868475996,"y":455.45302713987485,"name":"point"},"pe":{"x":786.8,"y":457.5,"name":"point"},"name":"segment"},{"ps":{"x":786.8,"y":457.5,"name":"point"},"pe":{"x":785.5,"y":458.5,"name":"point"},"name":"segment"},{"ps":{"x":785.5,"y":458.5,"name":"point"},"pe":{"x":782.5,"y":458.5,"name":"point"},"name":"segment"},{"ps":{"x":782.5,"y":458.5,"name":"point"},"pe":{"x":757.1344066237349,"y":460.2519779208832,"name":"point"},"name":"segment"},{"ps":{"x":757.1344066237349,"y":460.2519779208832,"name":"point"},"pe":{"x":748.3,"y":460.6,"name":"point"},"name":"segment"},{"ps":{"x":748.3,"y":460.6,"name":"point"},"pe":{"x":725.3,"y":460.3,"name":"point"},"name":"segment"},{"ps":{"x":725.3,"y":460.3,"name":"point"},"pe":{"x":645.6,"y":462,"name":"point"},"name":"segment"},{"ps":{"x":645.6,"y":462,"name":"point"},"pe":{"x":622.4,"y":462.3,"name":"point"},"name":"segment"},{"ps":{"x":622.4,"y":462.3,"name":"point"},"pe":{"x":605,"y":464.3,"name":"point"},"name":"segment"},{"ps":{"x":605,"y":464.3,"name":"point"},"pe":{"x":514.5186785260482,"y":466.0400254129607,"name":"point"},"name":"segment"},{"ps":{"x":514.5186785260482,"y":466.0400254129607,"name":"point"},"pe":{"x":513.8,"y":464.5,"name":"point"},"name":"segment"},{"ps":{"x":513.8,"y":464.5,"name":"point"},"pe":{"x":512.2,"y":463.5,"name":"point"},"name":"segment"},{"ps":{"x":512.2,"y":463.5,"name":"point"},"pe":{"x":510.8,"y":463.8,"name":"point"},"name":"segment"},{"ps":{"x":510.8,"y":463.8,"name":"point"},"pe":{"x":508.5535239810852,"y":466.1547399234408,"name":"point"},"name":"segment"},{"ps":{"x":508.5535239810852,"y":466.1547399234408,"name":"point"},"pe":{"x":501,"y":466.3,"name":"point"},"name":"segment"},{"ps":{"x":501,"y":466.3,"name":"point"},"pe":{"x":487,"y":467.6,"name":"point"},"name":"segment"},{"ps":{"x":487,"y":467.6,"name":"point"},"pe":{"x":496,"y":462.6,"name":"point"},"name":"segment"},{"ps":{"x":496,"y":462.6,"name":"point"},"pe":{"x":489.3,"y":451.6,"name":"point"},"name":"segment"},{"ps":{"x":489.3,"y":451.6,"name":"point"},"pe":{"x":493,"y":449.6,"name":"point"},"name":"segment"},{"ps":{"x":493,"y":449.6,"name":"point"},"pe":{"x":495.6999999999999,"y":449.6,"name":"point"},"name":"segment"}],[{"ps":{"x":611.3,"y":427.8,"name":"point"},"pe":{"x":612.3,"y":427.3,"name":"point"},"name":"segment"},{"ps":{"x":612.3,"y":427.3,"name":"point"},"pe":{"x":613.4,"y":425.9,"name":"point"},"name":"segment"},{"ps":{"x":613.4,"y":425.9,"name":"point"},"pe":{"x":612.3,"y":425.9,"name":"point"},"name":"segment"},{"ps":{"x":612.3,"y":425.9,"name":"point"},"pe":{"x":611.3,"y":427.8,"name":"point"},"name":"segment"}]]`;

            let poly1 = new Polygon(JSON.parse(json1));
            let poly2 = new Polygon(JSON.parse(json2));

            expect(poly1.faces.size).to.equal(3);
            expect(poly2.faces.size).to.equal(4);

            let res = unify(poly1, poly2);

            expect(res.faces.size).to.equal(3);
        });
    });
    describe('#Algorithms.Boolean Subtraction', function () {
        it('Can perform subtract. 2 intersecting polygons', function () {
            "use strict";

            let polygon1 = new Polygon();
            polygon1.addFace([
                point(-10, 0),
                point(-10, 20),
                point(10, 20),
                point(10, 0)
            ]);
            let polygon2 = new Polygon();
            polygon2.addFace([
                point(5, 10),
                point(5, 30),
                point(15, 30),
                point(15, 10)
            ]);

            let poly = subtract(polygon1, polygon2);
            expect(poly.faces.size).to.equal(1);
            expect(poly.edges.size).to.equal(6);
        });
        it('Can perform subtract. 1-face polygon split with 2nd to 2-faced polygon and vice a verse', function () {
            "use strict";

            let polygon1 = new Polygon();
            polygon1.addFace([
                point(-20, 0),
                point(-20, 20),
                point(20, 20),
                point(20, 0)
            ]);
            let polygon2 = new Polygon();
            polygon2.addFace([
                point(-5, -10),
                point(-5, 30),
                point(5, 30),
                point(5, -10)
            ]);

            expect([...polygon1.faces][0].orientation()).to.equal(Flatten.ORIENTATION.CW);
            expect([...polygon2.faces][0].orientation()).to.equal(Flatten.ORIENTATION.CW);

            let poly = subtract(polygon1, polygon2);

            expect(poly.faces.size).to.equal(2);
            expect(poly.edges.size).to.equal(8);

            poly = subtract(polygon2, polygon1);

            expect(poly.faces.size).to.equal(2);
            expect(poly.edges.size).to.equal(8);
        });
        it('Can perform subtract. 2 intersecting polygons produce 2-island result', function () {
            "use strict";

            let polygon1 = new Polygon();
            polygon1.addFace([point(100, 10), point(100, 300), point(400, 150), point(250, 10)]);

            let polygon2 = new Polygon();
            polygon2.addFace([point(450, 10), point(0, 150), point(300, 300), point(600, 300)]);

            let poly;
            poly = subtract(polygon1, polygon2);
            expect(poly.faces.size).to.equal(2);
            expect(poly.edges.size).to.equal(7);

            poly = subtract(polygon2, polygon1);
            expect(poly.faces.size).to.equal(2);
            expect(poly.edges.size).to.equal(9);
        });
        // it('Can perform (boolean) subtraction. First polygon inside the second', function () {
        //     "use strict";
        //
        //     let {Polygon, point} = Flatten;
        //
        //     let polygon1 = new Polygon();
        //     polygon1.addFace([point(100, 10), point(100, 300), point(400, 150), point(250, 10)]);
        //
        //     let polygon2 = new Polygon();
        //     polygon2.addFace([point(50, 0), point(50, 400), point(500, 400), point(500, 0)]);
        //
        //     let poly = subtract(polygon2, polygon1);
        //     expect(poly.faces.size).to.equal(2);
        //     expect(poly.edges.size).to.equal(8);
        //
        // });

        it('Can perform subtract big polygon from smaller polygon and get empty result (Issue #4)', function() {
            let polygon1 = new Polygon();
            polygon1.addFace([point(0,0), point(100, 0), point(100, 100), point(0, 100)]);

            let polygon2 = new Polygon();
            polygon2.addFace([point(10, 10), point(90, 10), point(90,90), point(10, 90)]);

            // polygon2 is completely inside polygon1, I expect the result polygon to be empty
            let polygon = subtract(polygon2, polygon1);

            expect(polygon.isEmpty()).to.be.true;
            expect(polygon.faces.size).to.equal(0);
            expect(polygon.edges.size).to.equal(0);
        });
        it("Can subtract one polygon from another and create a hole (Issue #7)", function() {
            const baseZ0Surface = [[[0, 0, 0], [10, 0, 0], [10, 10, 0], [0, 10, 0]]];
            const z0Surface = [[[1, 1, 0], [9, 1, 0], [9, 9, 0], [1, 9, 0]]]; // where is the hole?
// const z0Surface = [[[1, 1, 0], [9, 1, 0], [9, 9, 0], [1, 11, 0]]]; // subtraction works when not producing holes

            const a = new Polygon();
            for (const polygon of baseZ0Surface) {
                let face = a.addFace(polygon.map(([x, y]) => point(x, y)));
                if (face.orientation() !== Flatten.ORIENTATION.CCW) {
                    face.reverse();
                }
            }

            const b = new Polygon();
            for (const polygon of z0Surface) {
                let face = b.addFace(polygon.map(([x, y]) => point(x, y)));
                if (face.orientation() !== Flatten.ORIENTATION.CCW) {
                    face.reverse();
                }
            }

            const myPoly = subtract(a, b);

            expect(myPoly.faces.size).to.equal(2);
            expect(myPoly.edges.size).to.equal(8);
            expect([...myPoly.faces][0].orientation()).to.equal(Flatten.ORIENTATION.CCW);
            expect([...myPoly.faces][1].orientation()).to.equal(Flatten.ORIENTATION.CW);
        });
    });
    describe('#Algorithms.Boolean Intersection', function () {
        it('Can perform (boolean) intersection. 2 intersecting polygons', function () {
            "use strict";

            let polygon1 = new Polygon();
            polygon1.addFace([
                point(-10, 0),
                point(-10, 20),
                point(10, 20),
                point(10, 0)
            ]);

            let polygon2 = new Polygon();
            polygon2.addFace([
                point(5, 10),
                point(5, 30),
                point(15, 30),
                point(15, 10)
            ]);

            let poly = intersect(polygon1, polygon2);
            expect(poly.faces.size).to.equal(1);
            expect(poly.edges.size).to.equal(4);
            expect([...poly.faces][0].size).to.equal(4);
        });
        it('Can perform (boolean) intersection. Other 2 intersecting polygons', function () {
            "use strict";

            let polygon1 = new Polygon();
            polygon1.addFace([point(100, 10), point(100, 300), point(400, 150), point(250, 10)]);

            let polygon2 = new Polygon();
            polygon2.addFace([point(450, 10), point(0, 150), point(300, 300), point(600, 300)]);

            let poly = intersect(polygon1, polygon2);
            expect(poly.faces.size).to.equal(1);
            expect(poly.edges.size).to.equal(5);
            expect([...poly.faces][0].size).to.equal(5);
        });
        it('Can perform (boolean) intersection. First polygon inside the second', function () {
            "use strict";

            let polygon1 = new Polygon();
            polygon1.addFace([point(100, 10), point(100, 300), point(400, 150), point(250, 10)]);

            let polygon2 = new Polygon();
            polygon2.addFace([point(50, 0), point(50, 400), point(500, 400), point(500, 0)]);

            let poly = intersect(polygon1, polygon2);
            expect(poly.faces.size).to.equal(1);
            expect(poly.edges.size).to.equal(4);
            expect([...poly.faces][0].size).to.equal(4);
        });
        it("issue #42 Intersect does not seem to work when a second is inside first", function() {
            const item1 = new Polygon([[0, 30], [30, 30], [30, 0], [0, 0]]);
            const item2 = new Polygon([[10, 20], [20, 20], [20, 10], [10, 10]]);
            const intersection = intersect(item1, item2);

            expect(intersection.faces.size).to.equal(1);
            expect(intersection.edges.size).to.equal(4);
        })
        it("Issue #2 with intersection of circle and box", function() {
            "use strict"

            let myPoly = new Polygon();
            myPoly.addFace([point(50, 50), point(50,950), point(950, 950), point(950, 50)]);
            // myPoly.addFace([point(50, 50), point(950, 50), point(950, 950), point(50,950)]);

            let myCircle = new Polygon();
            myCircle.addFace([arc(point(0,1000),980, 0, 2*Math.PI, Flatten.CW)]);

            myPoly = intersect(myPoly, myCircle);

            myCircle = new Polygon();
            myCircle.addFace([arc(point(0,1000),780, 0, 2*Math.PI, Flatten.CW)]);
            myPoly = subtract(myPoly, myCircle);

            myCircle = new Polygon();
            myCircle.addFace([arc(point(1000,1000),1330, 0, 2*Math.PI, Flatten.CW)]);
            myPoly = intersect(myPoly,myCircle);

            myCircle = new Polygon();
            myCircle.addFace([arc(point(1000,1000),1130, 0, 2*Math.PI, Flatten.CW)]);
            myPoly = subtract(myPoly,myCircle);

            myCircle = new Polygon();
            myCircle.addFace([arc(point(1000,0),980, 0, 2*Math.PI, Flatten.CW)]);

            myPoly = intersect(myPoly, myCircle);

            expect(myPoly.faces.size).to.equal(1);
            expect(myPoly.edges.size).to.equal(6);
            expect([...myPoly.faces][0].size).to.equal(6);
            expect([...myPoly.faces][0].orientation()).to.equal(Flatten.ORIENTATION.CW);
        });
        it("Issue #3", function() {
            "use strict";

            let myPoly = new Polygon();
            myPoly.addFace([point(6, 6), point(6,114), point(114, 114), point(114, 6)]);
            // state.layers[state.layers.length] = Layers.newLayer(stage, layers).add(myPoly);  // 0

            let myCircle = new Polygon();
            myCircle.addFace([arc(point(0,0),84.5779281026111, 0, 2*Math.PI, Flatten.CW)]);
            // state.layers[state.layers.length] = Layers.newLayer(stage, layers).add(myCircle);  // 1

            myPoly = intersect(myPoly,myCircle);
            // state.layers[state.layers.length] = Layers.newLayer(stage, layers).add(myPoly);   // 2

            myCircle = new Polygon();
            myCircle.addFace([arc(point(0,0),84.49938828627135, 0, 2*Math.PI, Flatten.CW)]);
            // state.layers[state.layers.length] = Layers.newLayer(stage, layers).add(myCircle);  // 3

            myPoly = subtract(myPoly,myCircle);
            // state.layers[state.layers.length] = Layers.newLayer(stage, layers).add(myPoly);   // 4

            myCircle = new Polygon();
            myCircle.addFace([arc(point(0,120),84.8710637077582, 0, 2*Math.PI, Flatten.CW)]);
            // state.layers[state.layers.length] = Layers.newLayer(stage, layers).add(myCircle);  // 5

            myPoly = intersect(myPoly,myCircle);
            // state.layers[state.layers.length] = Layers.newLayer(stage, layers).add(myPoly);   // 6

            myCircle = new Polygon();
            myCircle.addFace([arc(point(0,120),84.79252389141845, 0, 2*Math.PI, Flatten.CW)]);
            // state.layers[state.layers.length] = Layers.newLayer(stage, layers).add(myCircle);  // 7

            myPoly = subtract(myPoly,myCircle);
            // state.layers[state.layers.length] = Layers.newLayer(stage, layers).add(myPoly);   // 8

            myCircle = new Polygon();
            myCircle.addFace([arc(point(120,120),85.20624291591454, 0, 2*Math.PI, Flatten.CW)]);
            // state.layers[state.layers.length] = Layers.newLayer(stage, layers).add(myCircle);  // 9

            myPoly = intersect(myPoly,myCircle);
            // state.layers[state.layers.length] = Layers.newLayer(stage, layers).add(myPoly);   // 10

            myCircle = new Polygon();
            myCircle.addFace([arc(point(120,120), 85.1277030995748, 0, 2*Math.PI, Flatten.CW)]);
            // state.layers[state.layers.length] = Layers.newLayer(stage, layers).add(myCircle);  // 11

            myPoly = subtract(myPoly,myCircle);
            // state.layers[state.layers.length] = Layers.newLayer(stage, layers).add(myPoly);   // 12

            expect(myPoly.faces.size).to.equal(1);
            expect(myPoly.edges.size).to.equal(7);
            expect([...myPoly.faces][0].size).to.equal(7);
            expect([...myPoly.faces][0].orientation()).to.equal(Flatten.ORIENTATION.CW);

        });
        it("Issue #8", function() {
            const a = [[[0.0038566398538067426,-0.05711818784841144,-1.1102230246251565e-16],[0.027451566277452343,0.010121095260507057,-1.1102230246251565e-16],[-0.007578939370510268,0.028567406105599685,0],[-0.007578939370510268,-0.05203184177985917,-1.1102230246251565e-16]],
                [[-0.030046587894975794,-0.042038623815088355,-4.440892098500626e-16],[-0.007578939370510268,-0.05203184177985917,-1.1102230246251565e-16],[-0.007578939370510268,0.028567406105599685,0],[-0.01714635591203731,0.033605401882281144,0]]];
            const b = [[[-0.007578939370510268,0.028567406105599685,0],[0.027451566277452343,0.010121095260507057,-1.1102230246251565e-16],[0.04688704952527964,0.0655070683716446,-3.3306690738754696e-16],[0.016656535759185374,0.08343556096136145,0],[-0.007578939370510275,0.08970655600740696,1.1102230246251565e-16]],
                [[-0.007578939370510268,0.028567406105599685,0],[-0.007578939370510275,0.08970655600740696,1.1102230246251565e-16],[-0.01714635591203731,0.033605401882281144,0]]];

            const fromSurface = (surface) => {
                const flattenPolygon = new Polygon();
                for (const polygon of surface) {
                    flattenPolygon.addFace(polygon.map(([x, y]) => point(x, y)));
                }
                return flattenPolygon;
            };

            const p1 = fromSurface(a);
            const p2 = fromSurface(b);

            const valid1 = p1.isValid()
            // const p = unify(p1, p2)

        });
        it("Subtract bug from flatten-js/core 1.2 onwards #15", function() {
            const poly = new Polygon();
            poly.addFace([point(200,0), point(200,200), point(0,200), point(0,0)])
            const cutter = new Polygon();
            cutter.addFace([point(100,0),point(100,200),point(200,200),point(200,0)])
            const reducedAreas = subtract(poly, cutter);

            expect(reducedAreas.faces.size).to.equal(1);
            expect(reducedAreas.edges.size).to.equal(7);
        });
    });
    describe("Boolean operations with empty polygon", function() {
        it ('Can operate with empty polygon', function() {
            const p1 = new Polygon([[[0, 0], [0, 100], [100, 100], [100, 0]]]);

            const p2 = new Polygon([[[0, 0], [0, 50], [50, 50], [50, 0]]]);

            const emptyP = new Polygon([]);

// Works
            const res1 = subtract(p1, p2);
            expect(res1.faces.size).to.equal(1);
            expect(res1.edges.size).to.equal(6);

            const res2 = subtract(p2, p1);
            expect(res2.faces.size).to.equal(0);
            expect(res2.edges.size).to.equal(0);
            expect(res2.isEmpty()).to.be.true;

// Do not work (see console)
            let res3;
            try {
                res3 = subtract(p1, emptyP);
            } catch (err) {
                console.log(err);
            }
            expect(res3.faces.size).to.equal(1);
            expect(res3.edges.size).to.equal(4);
            expect(equal(res3, p1)).to.be.true;

            let res4;
            try {
                res4 = subtract(emptyP, p1);
            } catch (err) {
                console.log(err);
            }
            expect(res4.isEmpty()).to.be.true;

            let res5;
            try {
                res5 = intersect(p1, emptyP);
            } catch (err) {
                console.log(err);
            }
            expect(res5.isEmpty()).to.be.true;

            let res6;
            try {
                res6 = intersect(emptyP, p1);
            } catch (err) {
                console.log(err);
            }
            expect(res6.isEmpty()).to.be.true;

        })
    })
});
